@@ -4,7 +4,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /* completion.c: completes words according to context (cmd/nick) */
@@ -572,7 +571,7 @@ completion_list_add_server_nicks (t_completion *completion)
                  ptr_channel = ptr_channel->next_channel)
             {
                 if ((!completion->channel || (t_irc_channel *)(completion->channel) != ptr_channel)
-                    && (ptr_channel->type == CHANNEL_TYPE_CHANNEL))
+                    && (ptr_channel->type == IRC_CHANNEL_TYPE_CHANNEL))
                 {
                     for (ptr_nick = ptr_channel->nicks; ptr_nick;
                          ptr_nick = ptr_nick->next_nick)
@@ -585,7 +584,7 @@ completion_list_add_server_nicks (t_completion *completion)
         }
         
         /* add current channel nicks at beginning */
-        if (completion->channel && (((t_irc_channel *)(completion->channel))->type == CHANNEL_TYPE_CHANNEL))
+        if (completion->channel && (((t_irc_channel *)(completion->channel))->type == IRC_CHANNEL_TYPE_CHANNEL))
         {
             for (ptr_nick = ((t_irc_channel *)(completion->channel))->nicks;
                  ptr_nick; ptr_nick = ptr_nick->next_nick)
@@ -617,7 +616,7 @@ completion_list_add_channel_nicks (t_completion *completion)
     
     if (completion->channel)
     {
-        if (((t_irc_channel *)(completion->channel))->type == CHANNEL_TYPE_CHANNEL)
+        if (((t_irc_channel *)(completion->channel))->type == IRC_CHANNEL_TYPE_CHANNEL)
         {
             /* add channel nicks */
             for (ptr_nick = ((t_irc_channel *)(completion->channel))->nicks;
@@ -646,8 +645,8 @@ completion_list_add_channel_nicks (t_completion *completion)
                                      ((t_irc_server *)(completion->server))->nick,
                                      1, WEELIST_POS_END);
         }
-        if ((((t_irc_channel *)(completion->channel))->type == CHANNEL_TYPE_PRIVATE)
-            || (((t_irc_channel *)(completion->channel))->type == CHANNEL_TYPE_DCC_CHAT))
+        if ((((t_irc_channel *)(completion->channel))->type == IRC_CHANNEL_TYPE_PRIVATE)
+            || (((t_irc_channel *)(completion->channel))->type == IRC_CHANNEL_TYPE_DCC_CHAT))
         {
             completion_list_add (completion,
                                  ((t_irc_channel *)(completion->channel))->name,
@@ -670,7 +669,7 @@ completion_list_add_channel_nicks_hosts (t_completion *completion)
     
     if (completion->channel)
     {
-        if (((t_irc_channel *)(completion->channel))->type == CHANNEL_TYPE_CHANNEL)
+        if (((t_irc_channel *)(completion->channel))->type == IRC_CHANNEL_TYPE_CHANNEL)
         {
             for (ptr_nick = ((t_irc_channel *)(completion->channel))->nicks;
                  ptr_nick; ptr_nick = ptr_nick->next_nick)
@@ -693,8 +692,8 @@ completion_list_add_channel_nicks_hosts (t_completion *completion)
                 }
             }
         }
-        if ((((t_irc_channel *)(completion->channel))->type == CHANNEL_TYPE_PRIVATE)
-             || (((t_irc_channel *)(completion->channel))->type == CHANNEL_TYPE_PRIVATE))
+        if ((((t_irc_channel *)(completion->channel))->type == IRC_CHANNEL_TYPE_PRIVATE)
+             || (((t_irc_channel *)(completion->channel))->type == IRC_CHANNEL_TYPE_PRIVATE))
         {
             completion_list_add (completion,
                                  ((t_irc_channel *)(completion->channel))->name,
@@ -854,7 +853,7 @@ completion_list_add_topic (t_completion *completion)
         if (cfg_irc_colors_send)
             string = (char *)gui_color_decode_for_user_entry ((unsigned char *)((t_irc_channel *)(completion->channel))->topic);
         else
-            string = (char *)gui_color_decode ((unsigned char *)((t_irc_channel *)(completion->channel))->topic, 0);
+            string = (char *)gui_color_decode ((unsigned char *)((t_irc_channel *)(completion->channel))->topic, 0, 0);
         completion_list_add (completion,
                              (string) ?
                              string : ((t_irc_channel *)(completion->channel))->topic,
@@ -1020,6 +1019,8 @@ completion_build_list_template (t_completion *completion, char *template)
                             free (word);
                             return;
                             break;
+                        case '*': /* repeat last completion (do nothing there) */
+                            break;
                         case 'a': /* alias */
                             completion_list_add_alias (completion);
                             break;
@@ -1115,8 +1116,10 @@ completion_build_list_template (t_completion *completion, char *template)
 void
 completion_build_list (t_completion *completion)
 {
-    char *template, *pos_space;
-    int max_arg, i;
+    char *template, *pos_template, *pos_space;
+    int repeat_last, max_arg, i, length;
+
+    repeat_last = 0;
     
     completion_get_command_infos (completion, &template, &max_arg);
     if (!template || (strcmp (template, "-") == 0) ||
@@ -1125,25 +1128,40 @@ completion_build_list (t_completion *completion)
         completion_stop (completion);
         return;
     }
-    i = 1;
-    while (template && template[0])
+
+    length = strlen (template);
+    if (length >= 2)
     {
-        pos_space = strchr (template, ' ');
+        if (strcmp (template + length - 2, "%*") == 0)
+            repeat_last = 1;
+    }
+    
+    i = 1;
+    pos_template = template;
+    while (pos_template && pos_template[0])
+    {
+        pos_space = strchr (pos_template, ' ');
         if (i == completion->base_command_arg)
         {
-            completion_build_list_template (completion, template);
+            completion_build_list_template (completion, pos_template);
             return;
         }
         if (pos_space)
         {
-            template = pos_space;
-            while (template[0] == ' ')
-                template++;
+            pos_template = pos_space;
+            while (pos_template[0] == ' ')
+                pos_template++;
         }
         else
-            template = NULL;
+            pos_template = NULL;
         i++;
     }
+    if (repeat_last)
+    {
+        pos_space = rindex (template, ' ');
+        completion_build_list_template (completion,
+                                        (pos_space) ? pos_space + 1 : template);
+    }
 }
 
 /*
@@ -1431,8 +1449,8 @@ completion_nick (t_completion *completion)
     
     completion->context = COMPLETION_NICK;
     
-    if ((((t_irc_channel *)(completion->channel))->type == CHANNEL_TYPE_PRIVATE)
-        || (((t_irc_channel *)(completion->channel))->type == CHANNEL_TYPE_DCC_CHAT))
+    if ((((t_irc_channel *)(completion->channel))->type == IRC_CHANNEL_TYPE_PRIVATE)
+        || (((t_irc_channel *)(completion->channel))->type == IRC_CHANNEL_TYPE_DCC_CHAT))
     {
         if (!(completion->completion_list))
         {
