@@ -4,7 +4,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /* utf8.c: UTF-8 string functions for WeeChat */
@@ -27,16 +26,6 @@
 #include <stdlib.h>
 #include <string.h>
 
-#ifndef __USE_XOPEN
-#define __USE_XOPEN
-#endif
-
-#if defined(__OpenBSD__)
-#include <utf8/wchar.h>
-#else
-#include <wchar.h>
-#endif
-
 #include "weechat.h"
 #include "utf8.h"
 #include "util.h"
@@ -395,3 +384,43 @@ utf8_pos (char *string, int real_pos)
     }
     return count;
 }
+
+/*
+ * utf8_get_wc: get wide char from string (first char)
+ */
+
+wint_t
+utf8_get_wc (char *string)
+{
+    int char_size;
+    wint_t result;
+    
+    if (!string || !string[0])
+        return WEOF;
+    
+    char_size = utf8_char_size (string);
+    switch (char_size)
+    {
+        case 1:
+            result = (wint_t)string[0];
+            break;
+        case 2:
+            result = ((wint_t)((unsigned char)string[0])) << 8
+                |  ((wint_t)((unsigned char)string[1]));
+            break;
+        case 3:
+            result = ((wint_t)((unsigned char)string[0])) << 16
+                |  ((wint_t)((unsigned char)string[1])) << 8
+                |  ((wint_t)((unsigned char)string[2]));
+            break;
+        case 4:
+            result = ((wint_t)((unsigned char)string[0])) << 24
+                |  ((wint_t)((unsigned char)string[1])) << 16
+                |  ((wint_t)((unsigned char)string[2])) << 8
+                |  ((wint_t)((unsigned char)string[3]));
+            break;
+        default:
+            result = WEOF;
+    }
+    return result;
+}
