@@ -4,7 +4,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,14 +13,23 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
 #ifndef __WEECHAT_UTF8_H
 #define __WEECHAT_UTF8_H 1
 
+#ifndef __USE_XOPEN
+#define __USE_XOPEN
+#endif
+
+#if defined(__OpenBSD__)
+#include <utf8/wchar.h>
+#else
+#include <wchar.h>
+#endif
+
 extern int local_utf8;
 
 extern void utf8_init ();
@@ -36,5 +45,6 @@ extern int utf8_width_screen (char *);
 extern char *utf8_add_offset (char *, int);
 extern int utf8_real_pos (char *, int);
 extern int utf8_pos (char *, int);
+extern wint_t utf8_get_wc (char *);
 
 #endif /* utf8.h */
