@@ -19,7 +19,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -28,8 +28,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /* weechat.c: core functions for WeeChat */
@@ -60,6 +59,7 @@
 #include "backtrace.h"
 #include "command.h"
 #include "fifo.h"
+#include "hotlist.h"
 #include "log.h"
 #include "session.h"
 #include "utf8.h"
@@ -187,8 +187,22 @@ weechat_display_config_options ()
                                                weechat_options[i][j].default_string : _("empty"));
                         break;
                     case OPTION_TYPE_STRING:
-                        weechat_iconv_fprintf (stdout, _("  . type: string\n"));
-                        weechat_iconv_fprintf (stdout, _("  . values: any string\n"));
+                        switch (weechat_options[i][j].max)
+                        {
+                            case 0:
+                                weechat_iconv_fprintf (stdout, _("  . type: string\n"));
+                                weechat_iconv_fprintf (stdout, _("  . values: any string\n"));
+                                break;
+                            case 1:
+                                weechat_iconv_fprintf (stdout, _("  . type: char\n"));
+                                weechat_iconv_fprintf (stdout, _("  . values: any char\n"));
+                                break;
+                            default:
+                                weechat_iconv_fprintf (stdout, _("  . type: string\n"));
+                                weechat_iconv_fprintf (stdout, _("  . values: any string (limit: %d chars)\n"),
+                                                       weechat_options[i][j].max);
+                                break;
+                        }
                         weechat_iconv_fprintf (stdout, _("  . default value: '%s'\n"),
                                                (weechat_options[i][j].default_string) ?
                                                weechat_options[i][j].default_string : _("empty"));
@@ -554,10 +568,6 @@ weechat_init_vars ()
     /* start time, used by /uptime command */
     weechat_start_time = time (NULL);
     
-    /* init received messages queue */
-    recv_msgq = NULL;
-    msgq_last_msg = NULL;
-    
     /* init gnutls */
 #ifdef HAVE_GNUTLS
     gnutls_global_init ();
@@ -604,17 +614,17 @@ weechat_welcome_message ()
                     "%s   __ | /| / /_  _ \\  _ \\  /    __  __ \\  __ `/  __/\n"
                     "%s   __ |/ |/ / /  __/  __/ /___  _  / / / /_/ // /_  \n"
                     "%s   ____/|__/  \\___/\\___/\\____/  /_/ /_/\\__,_/ \\__/  \n",
-                    GUI_COLOR(COLOR_WIN_CHAT_NICK),
-                    GUI_COLOR(COLOR_WIN_CHAT_NICK),
-                    GUI_COLOR(COLOR_WIN_CHAT_NICK),
-                    GUI_COLOR(COLOR_WIN_CHAT_NICK),
-                    GUI_COLOR(COLOR_WIN_CHAT_NICK));
+                    GUI_COLOR(GUI_COLOR_WIN_CHAT_NICK),
+                    GUI_COLOR(GUI_COLOR_WIN_CHAT_NICK),
+                    GUI_COLOR(GUI_COLOR_WIN_CHAT_NICK),
+                    GUI_COLOR(GUI_COLOR_WIN_CHAT_NICK),
+                    GUI_COLOR(GUI_COLOR_WIN_CHAT_NICK));
     }
     if (cfg_look_weechat_slogan && cfg_look_weechat_slogan[0])
     {
         gui_printf (NULL, _("%sWelcome to %s%s%s, %s\n"),
                     (cfg_look_startup_logo) ? "      " : "",
-                    GUI_COLOR(COLOR_WIN_CHAT_CHANNEL),
+                    GUI_COLOR(GUI_COLOR_WIN_CHAT_CHANNEL),
                     PACKAGE_NAME,
                     GUI_NO_COLOR,
                     cfg_look_weechat_slogan);
@@ -623,7 +633,7 @@ weechat_welcome_message ()
     {
         gui_printf (NULL, "%s%s%s%s, %s %s %s\n",
                     (cfg_look_startup_logo) ? "    " : "",
-                    GUI_COLOR(COLOR_WIN_CHAT_CHANNEL),
+                    GUI_COLOR(GUI_COLOR_WIN_CHAT_CHANNEL),
                     PACKAGE_STRING,
                     GUI_NO_COLOR,
                     _("compiled on"), __DATE__, __TIME__);
@@ -633,7 +643,7 @@ weechat_welcome_message ()
         cfg_look_startup_version)
         gui_printf (NULL,
                     "%s-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-\n",
-                    GUI_COLOR(COLOR_WIN_CHAT_NICK));
+                    GUI_COLOR(GUI_COLOR_WIN_CHAT_NICK));
     
     weechat_log_printf ("%s (%s %s %s)\n",
                         PACKAGE_STRING, _("compiled on"), __DATE__, __TIME__);
@@ -679,6 +689,9 @@ weechat_dump (int crash)
     t_irc_nick *ptr_nick;
     t_gui_window *ptr_window;
     t_gui_buffer *ptr_buffer;
+#ifdef PLUGINS
+    t_weechat_plugin *ptr_plugin;
+#endif
     
     /* prevent reentrance */
     if (sigsegv)
@@ -747,7 +760,8 @@ weechat_dump (int crash)
         gui_window_print_log (ptr_window);
     }
     
-    for (ptr_buffer = gui_buffers; ptr_buffer; ptr_buffer = ptr_buffer->next_buffer)
+    for (ptr_buffer = gui_buffers; ptr_buffer;
+         ptr_buffer = ptr_buffer->next_buffer)
     {
         weechat_log_printf ("\n");
         gui_buffer_print_log (ptr_buffer);
@@ -756,6 +770,18 @@ weechat_dump (int crash)
     weechat_log_printf ("\n");
     irc_ignore_print_log ();
     
+    weechat_log_printf ("\n");
+    hotlist_print_log ();
+    
+#ifdef PLUGINS
+    for (ptr_plugin = weechat_plugins; ptr_plugin;
+         ptr_plugin = ptr_plugin->next_plugin)
+    {
+        weechat_log_printf ("\n");
+        plugin_print_log (ptr_plugin);
+    }
+#endif
+    
     weechat_log_printf ("\n");
     weechat_log_printf ("******                 End of dump                 ******\n");
     weechat_log_printf ("\n");
@@ -801,8 +827,8 @@ weechat_sigsegv ()
 int
 main (int argc, char *argv[])
 {
-#ifdef ENABLE_NLS
     setlocale (LC_ALL, "");             /* initialize gettext               */
+#ifdef ENABLE_NLS
     bindtextdomain (PACKAGE, LOCALEDIR);
     bind_textdomain_codeset (PACKAGE, "UTF-8");
     textdomain (PACKAGE);
