@@ -4,7 +4,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -58,6 +57,13 @@
 #define CFG_LOOK_ALIGN_NICK_LEFT  1
 #define CFG_LOOK_ALIGN_NICK_RIGHT 2
 
+#define CFG_LOOK_HOTLIST_SORT_GROUP_TIME_ASC    0
+#define CFG_LOOK_HOTLIST_SORT_GROUP_TIME_DESC   1
+#define CFG_LOOK_HOTLIST_SORT_GROUP_NUMBER_ASC  2
+#define CFG_LOOK_HOTLIST_SORT_GROUP_NUMBER_DESC 3
+#define CFG_LOOK_HOTLIST_SORT_NUMBER_ASC        4
+#define CFG_LOOK_HOTLIST_SORT_NUMBER_DESC       5
+
 #define CFG_IRC_DISPLAY_AWAY_OFF     0
 #define CFG_IRC_DISPLAY_AWAY_LOCAL   1
 #define CFG_IRC_DISPLAY_AWAY_CHANNEL 2
@@ -112,6 +118,7 @@ extern int cfg_look_align_nick;
 extern int cfg_look_align_other;
 extern int cfg_look_align_size;
 extern int cfg_look_align_size_max;
+extern int cfg_look_align_text_offset;
 extern char *cfg_look_nick_completor;
 extern char *cfg_look_nick_completion_ignore;
 extern int cfg_look_nick_completion_smart;
@@ -123,10 +130,12 @@ extern int cfg_look_infobar_delay_highlight;
 extern int cfg_look_hotlist_names_count;
 extern int cfg_look_hotlist_names_level;
 extern int cfg_look_hotlist_names_length;
+extern int cfg_look_hotlist_sort;
 extern int cfg_look_day_change;
 extern char *cfg_look_day_change_timestamp;
 extern char *cfg_look_read_marker;
 extern char *cfg_look_input_format;
+extern int cfg_look_paste_max_lines;
 
 extern int cfg_col_real_white;
 extern int cfg_col_separator;
@@ -168,6 +177,7 @@ extern int cfg_col_input_channel;
 extern int cfg_col_input_nick;
 extern int cfg_col_input_delimiters;
 extern int cfg_col_input_text_not_found;
+extern int cfg_col_input_actions;
 extern int cfg_col_input_bg;
 extern int cfg_col_nick;
 extern int cfg_col_nick_away;
@@ -176,10 +186,11 @@ extern int cfg_col_nick_chanadmin;
 extern int cfg_col_nick_op;
 extern int cfg_col_nick_halfop;
 extern int cfg_col_nick_voice;
+extern int cfg_col_nick_user;
 extern int cfg_col_nick_more;
 extern int cfg_col_nick_sep;
 extern int cfg_col_nick_self;
-extern int cfg_col_nick_colors[COLOR_WIN_NICK_NUMBER];
+extern int cfg_col_nick_colors[GUI_COLOR_WIN_NICK_NUMBER];
 extern int cfg_col_nick_private;
 extern int cfg_col_nick_bg;
 extern int cfg_col_dcc_selected;
@@ -254,6 +265,7 @@ extern void config_change_save_on_exit ();
 extern void config_change_title ();
 extern void config_change_buffers ();
 extern void config_change_buffer_content ();
+extern void config_change_hotlist ();
 extern void config_change_read_marker ();
 extern void config_change_charset ();
 extern void config_change_one_server_buffer ();
