@@ -4,7 +4,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /* gui-curses-main.c: main loop for Curses GUI */
@@ -84,7 +83,7 @@ gui_main_loop ()
     
     old_min = -1;
     old_sec = -1;
-    check_away = 0;
+    irc_check_away = 0;
     
     /* if SIGTERM or SIGHUP received => quit */
     signal (SIGTERM, gui_main_quit);
@@ -115,7 +114,7 @@ gui_main_loop ()
                 for (ptr_buffer = gui_buffers; ptr_buffer;
                      ptr_buffer = ptr_buffer->next_buffer)
                 {
-                    if (ptr_buffer->type == BUFFER_TYPE_STANDARD)
+                    if (ptr_buffer->type == GUI_BUFFER_TYPE_STANDARD)
                         gui_printf_nolog_notime (ptr_buffer,
                                                  _("Day changed to %s\n"),
                                                  (text_time2) ?
@@ -166,10 +165,10 @@ gui_main_loop ()
             /* away check */
             if (cfg_irc_away_check != 0)
             {
-                check_away++;
-                if (check_away >= (cfg_irc_away_check * 60))
+                irc_check_away++;
+                if (irc_check_away >= (cfg_irc_away_check * 60))
                 {
-                    check_away = 0;
+                    irc_check_away = 0;
                     irc_server_check_away ();
                 }
             }
@@ -198,6 +197,8 @@ gui_main_loop ()
                 gui_keyboard_read ();
             }
         }
+        else
+            gui_keyboard_flush ();
 #endif
         
         /* read sockets (servers, child process when connecting, FIFO pipe) */
@@ -244,7 +245,7 @@ gui_main_loop ()
                         diff = (int) get_timeval_diff (&(ptr_server->lag_check_time), &tv);
                         if (diff / 1000 > cfg_irc_lag_disconnect * 60)
                         {
-                            irc_display_prefix (ptr_server, ptr_server->buffer, PREFIX_ERROR);
+                            irc_display_prefix (ptr_server, ptr_server->buffer, GUI_PREFIX_ERROR);
                             gui_printf (ptr_server->buffer,
                                         _("%s lag is high, disconnecting from server...\n"),
                                         WEECHAT_WARNING);
@@ -252,6 +253,14 @@ gui_main_loop ()
                             continue;
                         }
                     }
+
+                    /* check if it's time to autojoin channels (after command delay) */
+                    if ((ptr_server->command_time != 0)
+                        && (new_time >= ptr_server->command_time + ptr_server->command_delay))
+                    {
+                        irc_server_autojoin_channels (ptr_server);
+                        ptr_server->command_time = 0;
+                    }
                 }
             
                 if (!ptr_server->is_connected && (ptr_server->child_pid > 0))
@@ -324,7 +333,8 @@ gui_main_init ()
     curs_set (1);
     noecho ();
     nodelay (stdscr, TRUE);
-
+    raw ();
+    
     gui_color_init ();
     
     gui_infobar = NULL;
@@ -340,7 +350,7 @@ gui_main_init ()
     if (gui_window_new (NULL, 0, 0, COLS, LINES, 100, 100))
     {
         gui_current_window = gui_windows;
-        gui_buffer_new (gui_windows, NULL, NULL, BUFFER_TYPE_STANDARD, 1);
+        gui_buffer_new (gui_windows, NULL, NULL, GUI_BUFFER_TYPE_STANDARD, 1);
         
         if (cfg_look_set_title)
             gui_window_set_title ();
