@@ -4,7 +4,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /* gui-gtk-chat.c: chat display functions for Gtk GUI */
@@ -264,6 +263,7 @@ gui_chat_word_get_next_char (t_gui_window *window, unsigned char *string,
                 }
                 break;
             case GUI_ATTR_RESET_CHAR:
+            case GUI_ATTR_WEECHAT_RESET_CHAR:
                 string++;
                 if (apply_style)
                     gui_chat_reset_style (window);
@@ -629,7 +629,7 @@ gui_chat_draw_line (t_gui_buffer *buffer, t_gui_line *line)
     ptr_win = gui_buffer_find_window (buffer);
     if (ptr_win)
     {
-        text_without_color = gui_color_decode ((unsigned char *)(line->data), 0);
+        text_without_color = gui_color_decode ((unsigned char *)(line->data), 0, 0);
         if (text_without_color)
         {
             gtk_text_buffer_insert_at_cursor (GUI_GTK(ptr_win)->textbuffer_chat,
