@@ -4,7 +4,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /* gui-gtk-color.c: color functions for Gtk GUI */
@@ -113,16 +112,14 @@ gui_color_get_name (int num_color)
 
 /*
  * gui_color_decode: parses a message (coming from IRC server),
- *                   and according:
- *                     - remove any color/style in message
- *                   or:
- *                     - change colors by codes to be compatible with
- *                       other IRC clients
+ *                   if keep_colors == 0: remove any color/style in message
+ *                     otherwise change colors by internal WeeChat color codes
+ *                   if wkeep_eechat_attr == 0: remove any weechat color/style attribute
  *                   After use, string returned has to be free()
  */
 
 unsigned char *
-gui_color_decode (unsigned char *string, int keep_colors)
+gui_color_decode (unsigned char *string, int keep_irc_colors, int keep_weechat_attr)
 {
     unsigned char *out;
     int out_length, out_pos;
@@ -135,7 +132,7 @@ gui_color_decode (unsigned char *string, int keep_colors)
         return NULL;
     
     out_pos = 0;
-    while (string[0] && (out_pos < out_length - 1))
+    while (string && string[0] && (out_pos < out_length - 1))
     {
         switch (string[0])
         {
@@ -146,7 +143,7 @@ gui_color_decode (unsigned char *string, int keep_colors)
             case GUI_ATTR_REVERSE2_CHAR:
             case GUI_ATTR_ITALIC_CHAR:
             case GUI_ATTR_UNDERLINE_CHAR:
-                if (keep_colors)
+                if (keep_irc_colors)
                     out[out_pos++] = string[0];
                 string++;
                 break;
@@ -182,7 +179,7 @@ gui_color_decode (unsigned char *string, int keep_colors)
                         }
                     }
                 }
-                if (keep_colors)
+                if (keep_irc_colors)
                 {
                     if (!str_fg[0] && !str_bg[0])
                         out[out_pos++] = GUI_ATTR_COLOR_CHAR;
@@ -192,13 +189,13 @@ gui_color_decode (unsigned char *string, int keep_colors)
                         if (str_fg[0])
                         {
                             sscanf (str_fg, "%d", &fg);
-                            fg %= 16;
+                            fg %= GUI_NUM_IRC_COLORS;
                             attr |= gui_irc_colors[fg][1];
                         }
                         if (str_bg[0])
                         {
                             sscanf (str_bg, "%d", &bg);
-                            bg %= 16;
+                            bg %= GUI_NUM_IRC_COLORS;
                             attr |= gui_irc_colors[bg][1];
                         }
                         if (attr & A_BOLD)
@@ -227,10 +224,12 @@ gui_color_decode (unsigned char *string, int keep_colors)
                 }
                 break;
             case GUI_ATTR_WEECHAT_COLOR_CHAR:
+                if (keep_weechat_attr)
+                    out[out_pos++] = string[0];
                 string++;
                 if (isdigit (string[0]) && isdigit (string[1]))
                 {
-                    if (keep_colors)
+                    if (keep_weechat_attr)
                     {
                         out[out_pos++] = string[0];
                         out[out_pos++] = string[1];
@@ -240,17 +239,21 @@ gui_color_decode (unsigned char *string, int keep_colors)
                 break;
             case GUI_ATTR_WEECHAT_SET_CHAR:
             case GUI_ATTR_WEECHAT_REMOVE_CHAR:
+                if (keep_weechat_attr)
+                    out[out_pos++] = string[0];
                 string++;
                 if (string[0])
                 {
-                    if (keep_colors)
-                    {
-                        out[out_pos++] = *(string - 1);
+                    if (keep_weechat_attr)
                         out[out_pos++] = string[0];
-                    }
                     string++;
                 }
                 break;
+            case GUI_ATTR_WEECHAT_RESET_CHAR:
+                if (keep_weechat_attr)
+                    out[out_pos++] = string[0];
+                string++;
+                break;
             default:
                 out[out_pos++] = string[0];
                 string++;
@@ -262,7 +265,7 @@ gui_color_decode (unsigned char *string, int keep_colors)
 
 /*
  * gui_color_decode_for_user_entry: parses a message (coming from IRC server),
- *                                  and replaces colors/bold/.. by %C, %B, ..
+ *                                  and replaces colors/bold/.. by ^C, ^B, ..
  *                                  After use, string returned has to be free()
  */
 
@@ -278,40 +281,35 @@ gui_color_decode_for_user_entry (unsigned char *string)
         return NULL;
     
     out_pos = 0;
-    while (string[0] && (out_pos < out_length - 1))
+    while (string && string[0] && (out_pos < out_length - 1))
     {
         switch (string[0])
         {
             case GUI_ATTR_BOLD_CHAR:
-                out[out_pos++] = '%';
-                out[out_pos++] = 'B';
+                out[out_pos++] = 0x02; /* ^B */
                 string++;
                 break;
             case GUI_ATTR_FIXED_CHAR:
                 string++;
                 break;
             case GUI_ATTR_RESET_CHAR:
-                out[out_pos++] = '%';
-                out[out_pos++] = 'O';
+                out[out_pos++] = 0x0F; /* ^O */
                 string++;
                 break;
             case GUI_ATTR_REVERSE_CHAR:
             case GUI_ATTR_REVERSE2_CHAR:
-                out[out_pos++] = '%';
-                out[out_pos++] = 'R';
+                out[out_pos++] = 0x12; /* ^R */
                 string++;
                 break;
             case GUI_ATTR_ITALIC_CHAR:
                 string++;
                 break;
             case GUI_ATTR_UNDERLINE_CHAR:
-                out[out_pos++] = '%';
-                out[out_pos++] = 'R';
+                out[out_pos++] = 0x15; /* ^U */
                 string++;
                 break;
             case GUI_ATTR_COLOR_CHAR:
-                out[out_pos++] = '%';
-                out[out_pos++] = 'C';
+                out[out_pos++] = 0x03; /* ^C */
                 string++;
                 break;
             default:
@@ -325,12 +323,14 @@ gui_color_decode_for_user_entry (unsigned char *string)
 
 /*
  * gui_color_encode: parses a message (entered by user), and
- *                   encode special chars (%B, %C, ..) in IRC colors
+ *                   encode special chars (^Cb, ^Cc, ..) in IRC colors
+ *                   if keep_colors == 0: remove any color/style in message
+ *                   otherwise: keep colors
  *                   After use, string returned has to be free()
  */
 
 unsigned char *
-gui_color_encode (unsigned char *string)
+gui_color_encode (unsigned char *string, int keep_colors)
 {
     unsigned char *out;
     int out_length, out_pos;
@@ -341,72 +341,65 @@ gui_color_encode (unsigned char *string)
         return NULL;
     
     out_pos = 0;
-    while (string[0] && (out_pos < out_length - 1))
+    while (string && string[0] && (out_pos < out_length - 1))
     {
         switch (string[0])
         {
-            case '%':
+            case 0x02: /* ^B */
+                if (keep_colors)
+                    out[out_pos++] = GUI_ATTR_BOLD_CHAR;
                 string++;
-                switch (string[0])
+                break;
+            case 0x03: /* ^C */
+                if (keep_colors)
+                    out[out_pos++] = GUI_ATTR_COLOR_CHAR;
+                string++;
+                if (isdigit (string[0]))
                 {
-                    case '\0':
-                        out[out_pos++] = '%';
-                        break;
-                    case '%': /* double '%' replaced by single '%' */
+                    if (keep_colors)
                         out[out_pos++] = string[0];
+                    string++;
+                    if (isdigit (string[0]))
+                    {
+                        if (keep_colors)
+                            out[out_pos++] = string[0];
                         string++;
-                        break;
-                    case 'B': /* bold */
-                        out[out_pos++] = GUI_ATTR_BOLD_CHAR;
-                        string++;
-                        break;
-                    case 'C': /* color */
-                        out[out_pos++] = GUI_ATTR_COLOR_CHAR;
+                    }
+                }
+                if (string[0] == ',')
+                {
+                    if (keep_colors)
+                        out[out_pos++] = ',';
+                    string++;
+                    if (isdigit (string[0]))
+                    {
+                        if (keep_colors)
+                            out[out_pos++] = string[0];
                         string++;
                         if (isdigit (string[0]))
                         {
-                            out[out_pos++] = string[0];
+                            if (keep_colors)
+                                out[out_pos++] = string[0];
                             string++;
-                            if (isdigit (string[0]))
-                            {
-                                out[out_pos++] = string[0];
-                                string++;
-                            }
                         }
-                        if (string[0] == ',')
-                        {
-                            out[out_pos++] = ',';
-                            string++;
-                            if (isdigit (string[0]))
-                            {
-                                out[out_pos++] = string[0];
-                                string++;
-                                if (isdigit (string[0]))
-                                {
-                                out[out_pos++] = string[0];
-                                string++;
-                                }
-                            }
-                        }
-                        break;
-                    case 'O': /* reset */
-                        out[out_pos++] = GUI_ATTR_RESET_CHAR;
-                        string++;
-                        break;
-                    case 'R': /* reverse */
-                        out[out_pos++] = GUI_ATTR_REVERSE_CHAR;
-                        string++;
-                        break;
-                    case 'U': /* underline */
-                        out[out_pos++] = GUI_ATTR_UNDERLINE_CHAR;
-                        string++;
-                        break;
-                    default:
-                        out[out_pos++] = '%';
-                        out[out_pos++] = string[0];
-                        string++;
+                    }
                 }
                 break;
+            case 0x0F: /* ^O */
+                if (keep_colors)
+                    out[out_pos++] = GUI_ATTR_RESET_CHAR;
+                string++;
+                break;
+            case 0x12: /* ^R */
+                if (keep_colors)
+                    out[out_pos++] = GUI_ATTR_REVERSE_CHAR;
+                string++;
+                break;
+            case 0x15: /* ^U */
+                if (keep_colors)
+                    out[out_pos++] = GUI_ATTR_UNDERLINE_CHAR;
+                string++;
+                break;
             default:
                 out[out_pos++] = string[0];
                 string++;
@@ -486,63 +479,7 @@ gui_color_init_pairs ()
 void
 gui_color_init_weechat ()
 {
-    int i;
-    
-    gui_color[COLOR_WIN_SEPARATOR] = gui_color_build (COLOR_WIN_SEPARATOR, cfg_col_separator, cfg_col_separator);
-    gui_color[COLOR_WIN_TITLE] = gui_color_build (COLOR_WIN_TITLE, cfg_col_title, cfg_col_title_bg);
-    gui_color[COLOR_WIN_CHAT] = gui_color_build (COLOR_WIN_CHAT, cfg_col_chat, cfg_col_chat_bg);
-    gui_color[COLOR_WIN_CHAT_TIME] = gui_color_build (COLOR_WIN_CHAT_TIME, cfg_col_chat_time, cfg_col_chat_bg);
-    gui_color[COLOR_WIN_CHAT_TIME_SEP] = gui_color_build (COLOR_WIN_CHAT_TIME_SEP, cfg_col_chat_time_sep, cfg_col_chat_bg);
-    gui_color[COLOR_WIN_CHAT_PREFIX1] = gui_color_build (COLOR_WIN_CHAT_PREFIX1, cfg_col_chat_prefix1, cfg_col_chat_bg);
-    gui_color[COLOR_WIN_CHAT_PREFIX2] = gui_color_build (COLOR_WIN_CHAT_PREFIX2, cfg_col_chat_prefix2, cfg_col_chat_bg);
-    gui_color[COLOR_WIN_CHAT_SERVER] = gui_color_build (COLOR_WIN_CHAT_SERVER, cfg_col_chat_server, cfg_col_chat_bg);
-    gui_color[COLOR_WIN_CHAT_JOIN] = gui_color_build (COLOR_WIN_CHAT_JOIN, cfg_col_chat_join, cfg_col_chat_bg);
-    gui_color[COLOR_WIN_CHAT_PART] = gui_color_build (COLOR_WIN_CHAT_PART, cfg_col_chat_part, cfg_col_chat_bg);
-    gui_color[COLOR_WIN_CHAT_NICK] = gui_color_build (COLOR_WIN_CHAT_NICK, cfg_col_chat_nick, cfg_col_chat_bg);
-    gui_color[COLOR_WIN_CHAT_HOST] = gui_color_build (COLOR_WIN_CHAT_HOST, cfg_col_chat_host, cfg_col_chat_bg);
-    gui_color[COLOR_WIN_CHAT_CHANNEL] = gui_color_build (COLOR_WIN_CHAT_CHANNEL, cfg_col_chat_channel, cfg_col_chat_bg);
-    gui_color[COLOR_WIN_CHAT_DARK] = gui_color_build (COLOR_WIN_CHAT_DARK, cfg_col_chat_dark, cfg_col_chat_bg);
-    gui_color[COLOR_WIN_CHAT_HIGHLIGHT] = gui_color_build (COLOR_WIN_CHAT_HIGHLIGHT, cfg_col_chat_highlight, cfg_col_chat_bg);
-    gui_color[COLOR_WIN_CHAT_READ_MARKER] = gui_color_build (COLOR_WIN_CHAT_READ_MARKER, cfg_col_chat_read_marker, cfg_col_chat_read_marker_bg);
-    gui_color[COLOR_WIN_STATUS] = gui_color_build (COLOR_WIN_STATUS, cfg_col_status, cfg_col_status_bg);
-    gui_color[COLOR_WIN_STATUS_DELIMITERS] = gui_color_build (COLOR_WIN_STATUS_DELIMITERS, cfg_col_status_delimiters, cfg_col_status_bg);
-    gui_color[COLOR_WIN_STATUS_CHANNEL] = gui_color_build (COLOR_WIN_STATUS_CHANNEL, cfg_col_status_channel, cfg_col_status_bg);
-    gui_color[COLOR_WIN_STATUS_DATA_MSG] = gui_color_build (COLOR_WIN_STATUS_DATA_MSG, cfg_col_status_data_msg, cfg_col_status_bg);
-    gui_color[COLOR_WIN_STATUS_DATA_PRIVATE] = gui_color_build (COLOR_WIN_STATUS_DATA_PRIVATE, cfg_col_status_data_private, cfg_col_status_bg);
-    gui_color[COLOR_WIN_STATUS_DATA_HIGHLIGHT] = gui_color_build (COLOR_WIN_STATUS_DATA_HIGHLIGHT, cfg_col_status_data_highlight, cfg_col_status_bg);
-    gui_color[COLOR_WIN_STATUS_DATA_OTHER] = gui_color_build (COLOR_WIN_STATUS_DATA_OTHER, cfg_col_status_data_other, cfg_col_status_bg);
-    gui_color[COLOR_WIN_STATUS_MORE] = gui_color_build (COLOR_WIN_STATUS_MORE, cfg_col_status_more, cfg_col_status_bg);
-    gui_color[COLOR_WIN_INFOBAR] = gui_color_build (COLOR_WIN_INFOBAR, cfg_col_infobar, cfg_col_infobar_bg);
-    gui_color[COLOR_WIN_INFOBAR_DELIMITERS] = gui_color_build (COLOR_WIN_INFOBAR_DELIMITERS, cfg_col_infobar_delimiters, cfg_col_infobar_bg);
-    gui_color[COLOR_WIN_INFOBAR_HIGHLIGHT] = gui_color_build (COLOR_WIN_INFOBAR_HIGHLIGHT, cfg_col_infobar_highlight, cfg_col_infobar_bg);
-    gui_color[COLOR_WIN_INPUT] = gui_color_build (COLOR_WIN_INPUT, cfg_col_input, cfg_col_input_bg);
-    gui_color[COLOR_WIN_INPUT_CHANNEL] = gui_color_build (COLOR_WIN_INPUT_CHANNEL, cfg_col_input_channel, cfg_col_input_bg);
-    gui_color[COLOR_WIN_INPUT_NICK] = gui_color_build (COLOR_WIN_INPUT_NICK, cfg_col_input_nick, cfg_col_input_bg);
-    gui_color[COLOR_WIN_INPUT_DELIMITERS] = gui_color_build (COLOR_WIN_INPUT_DELIMITERS, cfg_col_input_delimiters, cfg_col_input_bg);
-    gui_color[COLOR_WIN_NICK] = gui_color_build (COLOR_WIN_NICK, cfg_col_nick, cfg_col_nick_bg);
-    gui_color[COLOR_WIN_NICK_AWAY] = gui_color_build (COLOR_WIN_NICK_AWAY, cfg_col_nick_away, cfg_col_nick_bg);
-    gui_color[COLOR_WIN_NICK_CHANOWNER] = gui_color_build (COLOR_WIN_NICK_CHANOWNER, cfg_col_nick_chanowner, cfg_col_nick_bg);
-    gui_color[COLOR_WIN_NICK_CHANADMIN] = gui_color_build (COLOR_WIN_NICK_CHANADMIN, cfg_col_nick_chanadmin, cfg_col_nick_bg);
-    gui_color[COLOR_WIN_NICK_OP] = gui_color_build (COLOR_WIN_NICK_OP, cfg_col_nick_op, cfg_col_nick_bg);
-    gui_color[COLOR_WIN_NICK_HALFOP] = gui_color_build (COLOR_WIN_NICK_HALFOP, cfg_col_nick_halfop, cfg_col_nick_bg);
-    gui_color[COLOR_WIN_NICK_VOICE] = gui_color_build (COLOR_WIN_NICK_VOICE, cfg_col_nick_voice, cfg_col_nick_bg);
-    gui_color[COLOR_WIN_NICK_MORE] = gui_color_build (COLOR_WIN_NICK_MORE, cfg_col_nick_more, cfg_col_nick_bg);
-    gui_color[COLOR_WIN_NICK_SEP] = gui_color_build (COLOR_WIN_NICK_SEP, cfg_col_nick_sep, cfg_col_nick_bg);
-    gui_color[COLOR_WIN_NICK_SELF] = gui_color_build (COLOR_WIN_NICK_SELF, cfg_col_nick_self, cfg_col_nick_bg);
-    gui_color[COLOR_WIN_NICK_PRIVATE] = gui_color_build (COLOR_WIN_NICK_PRIVATE, cfg_col_nick_private, cfg_col_nick_bg);
-
-    for (i = 0; i < COLOR_WIN_NICK_NUMBER; i++)
-    {
-        gui_color[COLOR_WIN_NICK_1 + i] = gui_color_build (COLOR_WIN_NICK_1 + i, cfg_col_nick_colors[i], cfg_col_chat_bg);
-    }
-        
-    gui_color[COLOR_DCC_SELECTED] = gui_color_build (COLOR_DCC_SELECTED, cfg_col_dcc_selected, cfg_col_chat_bg);
-    gui_color[COLOR_DCC_WAITING] = gui_color_build (COLOR_DCC_WAITING, cfg_col_dcc_waiting, cfg_col_chat_bg);
-    gui_color[COLOR_DCC_CONNECTING] = gui_color_build (COLOR_DCC_CONNECTING, cfg_col_dcc_connecting, cfg_col_chat_bg);
-    gui_color[COLOR_DCC_ACTIVE] = gui_color_build (COLOR_DCC_ACTIVE, cfg_col_dcc_active, cfg_col_chat_bg);
-    gui_color[COLOR_DCC_DONE] = gui_color_build (COLOR_DCC_DONE, cfg_col_dcc_done, cfg_col_chat_bg);
-    gui_color[COLOR_DCC_FAILED] = gui_color_build (COLOR_DCC_FAILED, cfg_col_dcc_failed, cfg_col_chat_bg);
-    gui_color[COLOR_DCC_ABORTED] = gui_color_build (COLOR_DCC_ABORTED, cfg_col_dcc_aborted, cfg_col_chat_bg);
+    /* TODO: write this function for Gtk */
 }
 
 /*
