@@ -4,7 +4,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /* gui-gtk-window.c: window display functions for Gtk GUI */
@@ -157,6 +156,16 @@ gui_window_redraw_buffer (t_gui_buffer *buffer)
     (void) buffer;
 }
 
+/*
+ * gui_window_redraw_all_buffers: redraw all buffers
+ */
+
+void
+gui_window_redraw_all_buffers ()
+{
+    /* TODO: write this function for Gtk */
+}
+
 /*
  * gui_window_switch_to_buffer: switch to another buffer
  */
@@ -184,7 +193,7 @@ gui_window_switch_to_buffer (t_gui_window *window, t_gui_buffer *buffer)
     {
         GUI_GTK(window)->textview_chat = gtk_text_view_new ();
         gtk_widget_show (GUI_GTK(window)->textview_chat);
-        gtk_container_add (GTK_CONTAINER (scrolledwindow_chat), GUI_GTK(window)->textview_chat);
+        gtk_container_add (GTK_CONTAINER (gui_gtk_scrolledwindow_chat), GUI_GTK(window)->textview_chat);
         gtk_widget_set_size_request (GUI_GTK(window)->textview_chat, 300, -1);
         gtk_text_view_set_editable (GTK_TEXT_VIEW (GUI_GTK(window)->textview_chat), FALSE);
         gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW (GUI_GTK(window)->textview_chat), FALSE);
@@ -196,11 +205,11 @@ gui_window_switch_to_buffer (t_gui_window *window, t_gui_buffer *buffer)
         gtk_text_buffer_get_bounds (GUI_GTK(window)->textbuffer_chat, &start, &end);
         gtk_text_buffer_apply_tag (GUI_GTK(window)->textbuffer_chat, GUI_GTK(window)->texttag_chat, &start, &end);
     }
-    if (BUFFER_IS_CHANNEL(buffer) && !GUI_GTK(window)->textbuffer_nicklist)
+    if (GUI_BUFFER_IS_CHANNEL(buffer) && !GUI_GTK(window)->textbuffer_nicklist)
     {
         GUI_GTK(window)->textview_nicklist = gtk_text_view_new ();
         gtk_widget_show (GUI_GTK(window)->textview_nicklist);
-        gtk_container_add (GTK_CONTAINER (scrolledwindow_nick), GUI_GTK(window)->textview_nicklist);
+        gtk_container_add (GTK_CONTAINER (gui_gtk_scrolledwindow_nick), GUI_GTK(window)->textview_nicklist);
         gtk_text_view_set_editable (GTK_TEXT_VIEW (GUI_GTK(window)->textview_nicklist), FALSE);
         gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW (GUI_GTK(window)->textview_nicklist), FALSE);
         
@@ -412,7 +421,7 @@ gui_window_nick_beginning (t_gui_window *window)
     if (!gui_ok)
         return;
     
-    if (BUFFER_HAS_NICKLIST(window->buffer))
+    if (GUI_BUFFER_HAS_NICKLIST(window->buffer))
     {
         if (window->win_nick_start > 0)
         {
@@ -434,10 +443,10 @@ gui_window_nick_end (t_gui_window *window)
     if (!gui_ok)
         return;
     
-    if (BUFFER_HAS_NICKLIST(window->buffer))
+    if (GUI_BUFFER_HAS_NICKLIST(window->buffer))
     {
         new_start =
-            CHANNEL(window->buffer)->nicks_count - window->win_nick_height;
+            GUI_CHANNEL(window->buffer)->nicks_count - window->win_nick_height;
         if (new_start < 0)
             new_start = 0;
         else if (new_start >= 1)
@@ -461,7 +470,7 @@ gui_window_nick_page_up (t_gui_window *window)
     if (!gui_ok)
         return;
     
-    if (BUFFER_HAS_NICKLIST(window->buffer))
+    if (GUI_BUFFER_HAS_NICKLIST(window->buffer))
     {
         if (window->win_nick_start > 0)
         {
@@ -483,11 +492,11 @@ gui_window_nick_page_down (t_gui_window *window)
     if (!gui_ok)
         return;
     
-    if (BUFFER_HAS_NICKLIST(window->buffer))
+    if (GUI_BUFFER_HAS_NICKLIST(window->buffer))
     {
-        if ((CHANNEL(window->buffer)->nicks_count > window->win_nick_height)
+        if ((GUI_CHANNEL(window->buffer)->nicks_count > window->win_nick_height)
             && (window->win_nick_start + window->win_nick_height - 1
-                < CHANNEL(window->buffer)->nicks_count))
+                < GUI_CHANNEL(window->buffer)->nicks_count))
         {
             if (window->win_nick_start == 0)
                 window->win_nick_start += (window->win_nick_height - 1);
