@@ -4,7 +4,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -76,17 +75,17 @@ struct t_gui_gtk_objects
 extern t_gui_color gui_weechat_colors[];
 extern int gui_irc_colors[GUI_NUM_IRC_COLORS][2];
 
-extern GtkWidget *gtk_main_window;
-extern GtkWidget *vbox1;
-extern GtkWidget *entry_topic;
-extern GtkWidget *notebook1;
-extern GtkWidget *vbox2;
-extern GtkWidget *hbox1;
-extern GtkWidget *hpaned1;
-extern GtkWidget *scrolledwindow_chat;
-extern GtkWidget *scrolledwindow_nick;
-extern GtkWidget *entry_input;
-extern GtkWidget *label1;
+extern GtkWidget *gui_gtk_main_window;
+extern GtkWidget *gui_gtk_vbox1;
+extern GtkWidget *gui_gtk_entry_topic;
+extern GtkWidget *gui_gtk_notebook1;
+extern GtkWidget *gui_gtk_vbox2;
+extern GtkWidget *gui_gtk_hbox1;
+extern GtkWidget *gui_gtk_hpaned1;
+extern GtkWidget *gui_gtk_scrolledwindow_chat;
+extern GtkWidget *gui_gtk_scrolledwindow_nick;
+extern GtkWidget *gui_gtk_entry_input;
+extern GtkWidget *gui_gtk_label1;
 
 /* color functions */
 extern int gui_color_get_pair (int);
