@@ -4,7 +4,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /* gui-common.c: display functions, used by all GUI */
@@ -40,6 +39,7 @@
 #include "../common/hotlist.h"
 #include "../common/log.h"
 #include "../common/utf8.h"
+#include "../common/util.h"
 #include "../irc/irc.h"
 
 
@@ -97,7 +97,7 @@ gui_action_return (t_gui_window *window, char *args)
     
     if (window->buffer->has_input)
     {
-        if (window->buffer->text_search != TEXT_SEARCH_DISABLED)
+        if (window->buffer->text_search != GUI_TEXT_SEARCH_DISABLED)
             gui_buffer_search_stop (window);
         else if (window->buffer->input_buffer_size > 0)
         {
@@ -118,7 +118,7 @@ gui_action_return (t_gui_window *window, char *args)
             window->buffer->ptr_history = NULL;
             gui_input_optimize_size (window->buffer);
             gui_input_draw (window->buffer, 0);
-            user_command (SERVER(window->buffer), CHANNEL(window->buffer),
+            user_command (GUI_SERVER(window->buffer), GUI_CHANNEL(window->buffer),
                           command, 0);
             free (command);
         }
@@ -136,7 +136,7 @@ gui_action_tab (t_gui_window *window, char *args)
     (void) args;
     
     if (window->buffer->has_input
-        && (window->buffer->text_search == TEXT_SEARCH_DISABLED))
+        && (window->buffer->text_search == GUI_TEXT_SEARCH_DISABLED))
     {
         completion_search (&(window->buffer->completion), 1,
                            window->buffer->input_buffer,
@@ -158,7 +158,7 @@ gui_action_tab_previous (t_gui_window *window, char *args)
     (void) args;
     
     if (window->buffer->has_input
-        && (window->buffer->text_search == TEXT_SEARCH_DISABLED))
+        && (window->buffer->text_search == GUI_TEXT_SEARCH_DISABLED))
     {
         completion_search (&(window->buffer->completion), -1,
                            window->buffer->input_buffer,
@@ -669,9 +669,9 @@ gui_action_up (t_gui_window *window, char *args)
     /* make C compiler happy */
     (void) args;
     
-    if (window->buffer->type == BUFFER_TYPE_DCC)
+    if (window->buffer->type == GUI_BUFFER_TYPE_DCC)
     {
-        if (dcc_list)
+        if (irc_dcc_list)
         {
             if (window->dcc_selected
                 && ((t_irc_dcc *)(window->dcc_selected))->prev_dcc)
@@ -689,7 +689,7 @@ gui_action_up (t_gui_window *window, char *args)
     }
     else if (window->buffer->has_input)
     {
-        if (window->buffer->text_search == TEXT_SEARCH_DISABLED)
+        if (window->buffer->text_search == GUI_TEXT_SEARCH_DISABLED)
         {
             if (window->buffer->ptr_history)
             {
@@ -743,7 +743,7 @@ gui_action_up (t_gui_window *window, char *args)
         else
         {
             /* search backward in buffer history */
-            window->buffer->text_search = TEXT_SEARCH_BACKWARD;
+            window->buffer->text_search = GUI_TEXT_SEARCH_BACKWARD;
             (void) gui_buffer_search_text (window);
         }
     }
@@ -760,7 +760,7 @@ gui_action_up_global (t_gui_window *window, char *args)
     (void) args;
     
     if (window->buffer->has_input
-        && (window->buffer->text_search == TEXT_SEARCH_DISABLED))
+        && (window->buffer->text_search == GUI_TEXT_SEARCH_DISABLED))
     {
         if (history_global_ptr)
         {
@@ -798,9 +798,9 @@ gui_action_down (t_gui_window *window, char *args)
     /* make C compiler happy */
     (void) args;
     
-    if (window->buffer->type == BUFFER_TYPE_DCC)
+    if (window->buffer->type == GUI_BUFFER_TYPE_DCC)
     {
-        if (dcc_list)
+        if (irc_dcc_list)
         {
             if (!window->dcc_selected
                 || ((t_irc_dcc *)(window->dcc_selected))->next_dcc)
@@ -814,14 +814,14 @@ gui_action_down (t_gui_window *window, char *args)
                             ((t_irc_dcc *)(window->dcc_first))->next_dcc;
                     else
                         window->dcc_first =
-                            dcc_list->next_dcc;
+                            irc_dcc_list->next_dcc;
                 }
                 if (window->dcc_selected)
                     window->dcc_selected =
                         ((t_irc_dcc *)(window->dcc_selected))->next_dcc;
                 else
                     window->dcc_selected =
-                        dcc_list->next_dcc;
+                        irc_dcc_list->next_dcc;
                 gui_chat_draw (window->buffer, 1);
                 gui_input_draw (window->buffer, 1);
             }
@@ -829,7 +829,7 @@ gui_action_down (t_gui_window *window, char *args)
     }
     else if (window->buffer->has_input)
     {
-        if (window->buffer->text_search == TEXT_SEARCH_DISABLED)
+        if (window->buffer->text_search == GUI_TEXT_SEARCH_DISABLED)
         {
             if (window->buffer->ptr_history)
             {
@@ -859,11 +859,28 @@ gui_action_down (t_gui_window *window, char *args)
                 }
                 gui_input_draw (window->buffer, 0);
             }
+            else
+            {
+                /* add line to history then clear input */
+                if (window->buffer->input_buffer_size > 0)
+                {
+                    window->buffer->input_buffer[window->buffer->input_buffer_size] = '\0';
+                    window->buffer->input_buffer_color_mask[window->buffer->input_buffer_size] = '\0';
+                    history_buffer_add (window->buffer, window->buffer->input_buffer);
+                    history_global_add (window->buffer->input_buffer);
+                    window->buffer->input_buffer_size = 0;
+                    window->buffer->input_buffer_length = 0;
+                    gui_input_optimize_size (window->buffer);
+                    window->buffer->input_buffer_pos = 0;
+                    window->buffer->input_buffer_1st_display = 0;
+                    gui_input_draw (window->buffer, 0);
+                }
+            }
         }
         else
         {
             /* search forward in buffer history */
-            window->buffer->text_search = TEXT_SEARCH_FORWARD;
+            window->buffer->text_search = GUI_TEXT_SEARCH_FORWARD;
             (void) gui_buffer_search_text (window);
         }
     }
@@ -880,7 +897,7 @@ gui_action_down_global (t_gui_window *window, char *args)
     (void) args;
     
     if (window->buffer->has_input
-        && (window->buffer->text_search == TEXT_SEARCH_DISABLED))
+        && (window->buffer->text_search == GUI_TEXT_SEARCH_DISABLED))
     {
         if (history_global_ptr)
         {
@@ -1078,13 +1095,13 @@ gui_action_jump_smart (t_gui_window *window, char *args)
     /* make C compiler happy */
     (void) args;
 
-    if (window->buffer->text_search == TEXT_SEARCH_DISABLED)
+    if (window->buffer->text_search == GUI_TEXT_SEARCH_DISABLED)
     {
-        if (hotlist)
+        if (weechat_hotlist)
         {
             if (!hotlist_initial_buffer)
                 hotlist_initial_buffer = window->buffer;
-            gui_window_switch_to_buffer (window, hotlist->buffer);
+            gui_window_switch_to_buffer (window, weechat_hotlist->buffer);
             gui_window_redraw_buffer (window->buffer);
         }
         else
@@ -1109,9 +1126,9 @@ gui_action_jump_dcc (t_gui_window *window, char *args)
     /* make C compiler happy */
     (void) args;
 
-    if (window->buffer->text_search == TEXT_SEARCH_DISABLED)
+    if (window->buffer->text_search == GUI_TEXT_SEARCH_DISABLED)
     {
-        if (window->buffer->type == BUFFER_TYPE_DCC)
+        if (window->buffer->type == GUI_BUFFER_TYPE_DCC)
         {
             if (gui_buffer_before_dcc)
             {
@@ -1138,9 +1155,9 @@ gui_action_jump_raw_data (t_gui_window *window, char *args)
     /* make C compiler happy */
     (void) args;
 
-    if (window->buffer->text_search == TEXT_SEARCH_DISABLED)
+    if (window->buffer->text_search == GUI_TEXT_SEARCH_DISABLED)
     {
-        if (window->buffer->type == BUFFER_TYPE_RAW_DATA)
+        if (window->buffer->type == GUI_BUFFER_TYPE_RAW_DATA)
         {
             if (gui_buffer_before_raw_data)
             {
@@ -1167,13 +1184,31 @@ gui_action_jump_last_buffer (t_gui_window *window, char *args)
     /* make C compiler happy */
     (void) args;
 
-    if (window->buffer->text_search == TEXT_SEARCH_DISABLED)
+    if (window->buffer->text_search == GUI_TEXT_SEARCH_DISABLED)
     {
         if (last_gui_buffer)
             gui_buffer_switch_by_number (window, last_gui_buffer->number);
     }
 }
 
+/*
+ * gui_action_jump_previous_buffer: jump to previous buffer (the one displayed
+ *                                  before current one)
+ */
+
+void
+gui_action_jump_previous_buffer (t_gui_window *window, char *args)
+{
+    /* make C compiler happy */
+    (void) args;
+    
+    if (window->buffer->text_search == GUI_TEXT_SEARCH_DISABLED)
+    {
+        if (gui_previous_buffer)
+            gui_buffer_switch_by_number (window, gui_previous_buffer->number);
+    }
+}
+
 /*
  * gui_action_jump_server: jump to server buffer
  */
@@ -1184,15 +1219,15 @@ gui_action_jump_server (t_gui_window *window, char *args)
     /* make C compiler happy */
     (void) args;
     
-    if (window->buffer->text_search == TEXT_SEARCH_DISABLED)
+    if (window->buffer->text_search == GUI_TEXT_SEARCH_DISABLED)
     {
-        if (SERVER(window->buffer))
+        if (GUI_SERVER(window->buffer))
         {
-            if (SERVER(window->buffer)->buffer !=
+            if (GUI_SERVER(window->buffer)->buffer !=
                 window->buffer)
             {
                 gui_window_switch_to_buffer (window,
-                                             SERVER(window->buffer)->buffer);
+                                             GUI_SERVER(window->buffer)->buffer);
                 gui_window_redraw_buffer (window->buffer);
             }
         }
@@ -1212,24 +1247,24 @@ gui_action_jump_next_server (t_gui_window *window, char *args)
     /* make C compiler happy */
     (void) args;
     
-    if (window->buffer->text_search == TEXT_SEARCH_DISABLED)
+    if (window->buffer->text_search == GUI_TEXT_SEARCH_DISABLED)
     {
-        if (SERVER(window->buffer))
+        if (GUI_SERVER(window->buffer))
         {
-            ptr_server = SERVER(window->buffer)->next_server;
+            ptr_server = GUI_SERVER(window->buffer)->next_server;
             if (!ptr_server)
                 ptr_server = irc_servers;
-            while (ptr_server != SERVER(window->buffer))
+            while (ptr_server != GUI_SERVER(window->buffer))
             {
                 if (ptr_server->buffer)
                     break;
                 ptr_server = (ptr_server->next_server) ?
                     ptr_server->next_server : irc_servers;
             }
-            if (ptr_server != SERVER(window->buffer))
+            if (ptr_server != GUI_SERVER(window->buffer))
             {
                 /* save current buffer */
-                SERVER(window->buffer)->saved_buffer = window->buffer;
+                GUI_SERVER(window->buffer)->saved_buffer = window->buffer;
                 
                 /* come back to memorized chan if found */
                 if (ptr_server->saved_buffer)
@@ -1273,8 +1308,8 @@ gui_action_scroll_previous_highlight (t_gui_window *window, char *args)
     /* make C compiler happy */
     (void) args;
     
-    if ((window->buffer->type == BUFFER_TYPE_STANDARD)
-        && (window->buffer->text_search == TEXT_SEARCH_DISABLED))
+    if ((window->buffer->type == GUI_BUFFER_TYPE_STANDARD)
+        && (window->buffer->text_search == GUI_TEXT_SEARCH_DISABLED))
     {
         if (window->buffer->lines)
         {
@@ -1310,8 +1345,8 @@ gui_action_scroll_next_highlight (t_gui_window *window, char *args)
     /* make C compiler happy */
     (void) args;
     
-    if ((window->buffer->type == BUFFER_TYPE_STANDARD)
-        && (window->buffer->text_search == TEXT_SEARCH_DISABLED))
+    if ((window->buffer->type == GUI_BUFFER_TYPE_STANDARD)
+        && (window->buffer->text_search == GUI_TEXT_SEARCH_DISABLED))
     {
         if (window->buffer->lines)
         {
@@ -1345,11 +1380,11 @@ gui_action_scroll_unread (t_gui_window *window, char *args)
     /* make C compiler happy */
     (void) args;
 
-    if (window->buffer->text_search == TEXT_SEARCH_DISABLED)
+    if (window->buffer->text_search == GUI_TEXT_SEARCH_DISABLED)
     {
         if (cfg_look_read_marker &&
             cfg_look_read_marker[0] &&
-            (window->buffer->type == BUFFER_TYPE_STANDARD) &&
+            (window->buffer->type == GUI_BUFFER_TYPE_STANDARD) &&
             window->buffer->last_read_line &&
             window->buffer->last_read_line != window->buffer->last_line)
         {
@@ -1363,6 +1398,31 @@ gui_action_scroll_unread (t_gui_window *window, char *args)
     }
 }
 
+/*
+ * gui_action_set_unread: set unread marker for all buffers
+ */
+
+void
+gui_action_set_unread (t_gui_window *window, char *args)
+{
+    t_gui_buffer *ptr_buffer;
+    
+    /* make C compiler happy */
+    (void) window;
+    (void) args;
+
+    /* set read marker for all standard buffers */
+    for (ptr_buffer = gui_buffers; ptr_buffer;
+         ptr_buffer = ptr_buffer->next_buffer)
+    {
+        if (ptr_buffer->type == GUI_BUFFER_TYPE_STANDARD)
+            ptr_buffer->last_read_line = ptr_buffer->last_line;
+    }
+    
+    /* refresh all windows */
+    gui_window_redraw_all_buffers ();
+}
+
 /*
  * gui_action_hotlist_clear: clear hotlist
  */
@@ -1373,9 +1433,9 @@ gui_action_hotlist_clear (t_gui_window *window, char *args)
     /* make C compiler happy */
     (void) args;
     
-    if (hotlist)
+    if (weechat_hotlist)
     {
-        hotlist_free_all ();
+        hotlist_free_all (&weechat_hotlist, &last_weechat_hotlist);
         gui_window_redraw_buffer (window->buffer);
     }
     hotlist_initial_buffer = window->buffer;
@@ -1420,7 +1480,7 @@ gui_action_grab_key (t_gui_window *window, char *args)
     (void) args;
     
     if (window->buffer->has_input)
-        gui_keyboard_init_grab ();
+        gui_keyboard_grab_init ();
 }
 
 /*
@@ -1430,10 +1490,16 @@ gui_action_grab_key (t_gui_window *window, char *args)
 void
 gui_action_insert_string (t_gui_window *window, char *args)
 {
+    char *args2;
+    
     if (args)
     {
-        gui_insert_string_input (window, args, -1);
+        args2 = weechat_convert_hex_chars (args);
+        gui_insert_string_input (window,
+                                 (args2) ? args2 : args, -1);
         gui_input_draw (window->buffer, 0);
+        if (args2)
+            free (args2);
     }
 }
 
@@ -1447,10 +1513,10 @@ gui_action_search_text (t_gui_window *window, char *args)
     /* make C compiler happy */
     (void) args;
     
-    if (window->buffer->type == BUFFER_TYPE_STANDARD)
+    if (window->buffer->type == GUI_BUFFER_TYPE_STANDARD)
     {
         /* toggle search */
-        if (window->buffer->text_search == TEXT_SEARCH_DISABLED)
+        if (window->buffer->text_search == GUI_TEXT_SEARCH_DISABLED)
             gui_buffer_search_start (window);
         else
         {
