@@ -4,7 +4,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /* gui-keyboard: keyboard functions (GUI independant) */
@@ -39,12 +38,20 @@
 #endif
 
 
-t_gui_key *gui_keys = NULL;
-t_gui_key *last_gui_key = NULL;
+t_gui_key *gui_keys = NULL;         /* key bindings                           */
+t_gui_key *last_gui_key = NULL;     /* last key binding                       */
 
-char gui_key_buffer[128];
-int gui_key_grab = 0;
-int gui_key_grab_count = 0;
+char gui_key_combo_buffer[128];     /* buffer used for combos                 */
+int gui_key_grab = 0;               /* 1 if grab mode enabled (alt-k pressed) */
+int gui_key_grab_count = 0;         /* number of keys pressed in grab mode    */
+
+int *gui_keyboard_buffer = NULL;    /* input buffer (for paste detection)     */
+int gui_keyboard_buffer_alloc = 0;  /* input buffer allocated size            */
+int gui_keyboard_buffer_size = 0;   /* input buffer size in bytes             */
+
+int gui_keyboard_paste_pending = 0; /* 1 is big paste was detected and        */
+                                    /* WeeChat is asking user what to do      */
+int gui_keyboard_paste_lines = 0;   /* number of lines for pending paste      */
 
 t_gui_key_function gui_key_functions[] =
 { { "return",                    gui_action_return,
@@ -123,6 +130,8 @@ t_gui_key_function gui_key_functions[] =
     N_("jump to raw IRC data buffer") },
   { "jump_last_buffer",          gui_action_jump_last_buffer,
     N_("jump to last buffer") },
+  { "jump_previous_buffer",      gui_action_jump_previous_buffer,
+    N_("jump to previous buffer") },
   { "jump_server",               gui_action_jump_server,
     N_("jump to server buffer") },
   { "jump_next_server",          gui_action_jump_next_server,
@@ -135,6 +144,8 @@ t_gui_key_function gui_key_functions[] =
     N_("scroll to next highlight in buffer") },
   { "scroll_unread",             gui_action_scroll_unread,
     N_("scroll to first unread line in buffer") },
+  { "set_unread",                gui_action_set_unread,
+    N_("set unread marker on all buffers") },
   { "hotlist_clear",             gui_action_hotlist_clear,
     N_("clear hotlist") },
   { "infobar_clear",             gui_action_infobar_clear,
@@ -158,7 +169,7 @@ t_gui_key_function gui_key_functions[] =
 void
 gui_keyboard_init ()
 {
-    gui_key_buffer[0] = '\0';
+    gui_key_combo_buffer[0] = '\0';
     gui_key_grab = 0;
     gui_key_grab_count = 0;
     
@@ -166,16 +177,45 @@ gui_keyboard_init ()
 }
 
 /*
- * gui_keyboard_init_show: init "show mode"
+ * gui_keyboard_grab_init: init "grab" mode
  */
 
 void
-gui_keyboard_init_grab ()
+gui_keyboard_grab_init ()
 {
     gui_key_grab = 1;
     gui_key_grab_count = 0;
 }
 
+/*
+ * gui_keyboard_grab_end: insert grabbed key in input buffer
+ */
+
+void
+gui_keyboard_grab_end ()
+{
+    char *expanded_key;
+    
+    /* get expanded name (for example: ^U => ctrl-u) */
+    expanded_key = gui_keyboard_get_expanded_name (gui_key_combo_buffer);
+    
+    if (expanded_key)
+    {
+        if (gui_current_window->buffer->has_input)
+        {
+            gui_insert_string_input (gui_current_window, expanded_key, -1);
+            gui_current_window->buffer->completion.position = -1;
+            gui_input_draw (gui_current_window->buffer, 0);
+        }
+        free (expanded_key);
+    }
+    
+    /* end grab mode */
+    gui_key_grab = 0;
+    gui_key_grab_count = 0;
+    gui_key_combo_buffer[0] = '\0';
+}
+
 /*
  * gui_keyboard_get_internal_code: get internal code from user key name
  *                                 for example: return "^R" for "ctrl-R"
@@ -470,7 +510,7 @@ gui_keyboard_bind (char *key, char *command)
 {
     t_gui_key_func *ptr_function;
     t_gui_key *new_key;
-    char *ptr_args;
+    char *command2, *ptr_args;
     
     if (!key || !command)
     {
@@ -481,18 +521,24 @@ gui_keyboard_bind (char *key, char *command)
     
     ptr_function = NULL;
     ptr_args = NULL;
+    
     if (command[0] != '/')
     {
         ptr_args = strchr (command, ' ');
         if (ptr_args)
-            ptr_args[0] = '\0';
-        ptr_function = gui_keyboard_function_search_by_name (command);
-        if (ptr_args)
+            command2 = strndup (command, ptr_args - command);
+        else
+            command2 = strdup (command);
+        if (command2)
         {
-            ptr_args[0] = ' ';
-            ptr_args++;
-            while (ptr_args[0] == ' ')
+            ptr_function = gui_keyboard_function_search_by_name (command2);
+            if (ptr_args)
+            {
                 ptr_args++;
+                while (ptr_args[0] == ' ')
+                    ptr_args++;
+            }
+            free (command2);
         }
         if (!ptr_function)
         {
@@ -555,8 +601,8 @@ gui_keyboard_pressed (char *key_str)
     char **commands, **ptr_cmd;
     
     /* add key to buffer */
-    first_key = (gui_key_buffer[0] == '\0');
-    strcat (gui_key_buffer, key_str);
+    first_key = (gui_key_combo_buffer[0] == '\0');
+    strcat (gui_key_combo_buffer, key_str);
     
     /* if we are in "show mode", increase counter and return */
     if (gui_key_grab)
@@ -566,16 +612,16 @@ gui_keyboard_pressed (char *key_str)
     }
     
     /* look for key combo in key table */
-    ptr_key = gui_keyboard_search_part (gui_key_buffer);
+    ptr_key = gui_keyboard_search_part (gui_key_combo_buffer);
     if (ptr_key)
     {
-        if (ascii_strcasecmp (ptr_key->key, gui_key_buffer) == 0)
+        if (ascii_strcasecmp (ptr_key->key, gui_key_combo_buffer) == 0)
         {
             /* exact combo found => execute function or command */
             buffer_before_key =
                 (gui_current_window->buffer->input_buffer) ?
                 strdup (gui_current_window->buffer->input_buffer) : strdup ("");
-            gui_key_buffer[0] = '\0';
+            gui_key_combo_buffer[0] = '\0';
             if (ptr_key->command)
             {
                 commands = split_multi_command (ptr_key->command, ';');
@@ -583,8 +629,8 @@ gui_keyboard_pressed (char *key_str)
                 {
                     for (ptr_cmd = commands; *ptr_cmd; ptr_cmd++)
                     {
-                        user_command (SERVER(gui_current_window->buffer),
-                                      CHANNEL(gui_current_window->buffer),
+                        user_command (GUI_SERVER(gui_current_window->buffer),
+                                      GUI_CHANNEL(gui_current_window->buffer),
                                       *ptr_cmd, 0);
                     }
                     free_multi_command (commands);
@@ -593,7 +639,7 @@ gui_keyboard_pressed (char *key_str)
             else
                 (void)(ptr_key->function)(gui_current_window, ptr_key->args);
 #ifdef PLUGINS
-            if (gui_current_window->buffer->text_search == TEXT_SEARCH_DISABLED)
+            if (gui_current_window->buffer->text_search == GUI_TEXT_SEARCH_DISABLED)
             {
                 (void) plugin_keyboard_handler_exec (
                     (ptr_key->command) ?
@@ -608,7 +654,7 @@ gui_keyboard_pressed (char *key_str)
         return 0;
     }
     
-    gui_key_buffer[0] = '\0';
+    gui_key_combo_buffer[0] = '\0';
 
     /* if this is first key and not found (even partial) => return 1
        else return 0 (= silently discard sequence of bad keys) */
@@ -653,3 +699,114 @@ gui_keyboard_free_all ()
     while (gui_keys)
         gui_keyboard_free (gui_keys);
 }
+
+/*
+ * gui_keyboard_buffer_optimize: optimize keyboard buffer size
+ */
+
+void
+gui_keyboard_buffer_optimize ()
+{
+    int optimal_size;
+    
+    optimal_size = (((gui_keyboard_buffer_size * sizeof (int)) /
+                     GUI_KEYBOARD_BUFFER_BLOCK_SIZE) *
+                    GUI_KEYBOARD_BUFFER_BLOCK_SIZE) +
+        GUI_KEYBOARD_BUFFER_BLOCK_SIZE;
+    
+    if (gui_keyboard_buffer_alloc != optimal_size)
+    {
+        gui_keyboard_buffer_alloc = optimal_size;
+        gui_keyboard_buffer = realloc (gui_keyboard_buffer, optimal_size);
+    }
+}
+
+/*
+ * gui_keyboard_buffer_reset: reset keyboard buffer
+ *                            (create empty if never created before)
+ */
+
+void
+gui_keyboard_buffer_reset ()
+{
+    if (!gui_keyboard_buffer)
+    {
+        gui_keyboard_buffer_alloc = GUI_KEYBOARD_BUFFER_BLOCK_SIZE;
+        gui_keyboard_buffer_size = 0;
+        gui_keyboard_buffer = (int *) malloc (gui_keyboard_buffer_alloc);
+    }
+    else
+    {
+        gui_keyboard_buffer_size = 0;
+        gui_keyboard_buffer_optimize ();
+    }
+    gui_keyboard_paste_lines = 0;
+}
+
+/*
+ * gui_keyboard_buffer_add: add a key to keyboard buffer
+ */
+
+void
+gui_keyboard_buffer_add (int key)
+{
+    if (!gui_keyboard_buffer)
+        gui_keyboard_buffer_reset ();
+    
+    gui_keyboard_buffer_size++;
+    
+    gui_keyboard_buffer_optimize ();
+    
+    if (gui_keyboard_buffer)
+    {
+        gui_keyboard_buffer[gui_keyboard_buffer_size - 1] = key;
+        if ((key == 10)
+            && (gui_keyboard_buffer_size > 1)
+            && (gui_keyboard_buffer[gui_keyboard_buffer_size - 2] != 10))
+            gui_keyboard_paste_lines++;
+    }
+    else
+    {
+        gui_keyboard_buffer_alloc = 0;
+        gui_keyboard_buffer_size = 0;
+        gui_keyboard_paste_lines = 0;
+    }
+}
+
+/*
+ * gui_keyboard_get_paste_lines: return real number of lines in buffer
+ *                               if last key is not Return, then this is lines + 1
+ *                               else it's lines
+ */
+
+int
+gui_keyboard_get_paste_lines ()
+{
+    if ((gui_keyboard_buffer_size > 0)
+        && (gui_keyboard_buffer[gui_keyboard_buffer_size - 1] != 10))
+        return gui_keyboard_paste_lines + 1;
+    
+    return gui_keyboard_paste_lines;
+}
+
+/*
+ * gui_keyboard_paste_accept: accept paste from user
+ */
+
+void
+gui_keyboard_paste_accept ()
+{
+    gui_keyboard_paste_pending = 0;
+}
+
+
+/*
+ * gui_keyboard_paste_cancel: cancel paste from user (reset buffer)
+ */
+
+void
+gui_keyboard_paste_cancel ()
+{
+    gui_keyboard_buffer_reset ();
+    gui_keyboard_paste_pending = 0;
+}
