@@ -4,7 +4,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /* gui-window.c: window functions, used by all GUI */
@@ -316,9 +315,10 @@ gui_window_switch_server (t_gui_window *window)
     
     if (ptr_buffer)
     {
-        ptr_server = (SERVER(ptr_buffer) && SERVER(ptr_buffer)->next_server) ?
-            SERVER(ptr_buffer)->next_server : irc_servers;
-        while (ptr_server != SERVER(window->buffer))
+        ptr_server = (GUI_SERVER(ptr_buffer)
+                      && GUI_SERVER(ptr_buffer)->next_server) ?
+            GUI_SERVER(ptr_buffer)->next_server : irc_servers;
+        while (ptr_server != GUI_SERVER(window->buffer))
         {
             if (ptr_server->buffer)
                 break;
@@ -326,7 +326,7 @@ gui_window_switch_server (t_gui_window *window)
                 ptr_server = ptr_server->next_server;
             else
             {
-                if (SERVER(ptr_buffer) == NULL)
+                if (GUI_SERVER(ptr_buffer) == NULL)
                 {
                     ptr_server = NULL;
                     break;
@@ -334,7 +334,7 @@ gui_window_switch_server (t_gui_window *window)
                 ptr_server = irc_servers;
             }
         }
-        if (ptr_server && (ptr_server != SERVER(ptr_buffer)))
+        if (ptr_server && (ptr_server != GUI_SERVER(ptr_buffer)))
         {
             ptr_buffer->server = ptr_server;
             gui_status_draw (window->buffer, 1);
