@@ -4,7 +4,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /* irc-server.c: connection and communication with IRC server */
@@ -58,11 +57,10 @@
 t_irc_server *irc_servers = NULL;
 t_irc_server *last_irc_server = NULL;
 
-t_irc_message *recv_msgq, *msgq_last_msg;
+t_irc_message *irc_recv_msgq = NULL;
+t_irc_message *irc_msgq_last_msg = NULL;
 
-int check_away = 0;
-
-char *nick_modes = "aiwroOs";
+int irc_check_away = 0;
 
 #ifdef HAVE_GNUTLS
 const int gnutls_cert_type_prio[] = { GNUTLS_CRT_X509, GNUTLS_CRT_OPENPGP, 0 };
@@ -88,7 +86,7 @@ irc_server_init (t_irc_server *server)
     server->autoconnect = 0;
     server->autoreconnect = 1;
     server->autoreconnect_delay = 30;
-    server->command_line = 0;
+    server->temp_server = 0;
     server->address = NULL;
     server->port = -1;
     server->ipv6 = 0;
@@ -118,7 +116,9 @@ irc_server_init (t_irc_server *server)
     server->nick_modes = NULL;
     server->prefix = NULL;
     server->reconnect_start = 0;
+    server->command_time = 0;
     server->reconnect_join = 0;
+    server->disable_autojoin = 0;
     server->is_away = 0;
     server->away_message = NULL;
     server->away_time = 0;
@@ -250,7 +250,7 @@ irc_server_init_with_url (char *irc_url, t_irc_server *server)
 
     /* some default values */
     if (server->port < 0)
-        server->port = DEFAULT_IRC_PORT;
+        server->port = IRC_DEFAULT_PORT;
     server->nick2 = (char *) malloc (strlen (server->nick1) + 2);
     strcpy (server->nick2, server->nick1);
     server->nick2 = strcat (server->nick2, "1");
@@ -468,7 +468,7 @@ irc_server_free_all ()
 
 t_irc_server *
 irc_server_new (char *name, int autoconnect, int autoreconnect,
-                int autoreconnect_delay, int command_line, char *address,
+                int autoreconnect_delay, int temp_server, char *address,
                 int port, int ipv6, int ssl, char *password,
                 char *nick1, char *nick2, char *nick3, char *username,
                 char *realname, char *hostname, char *command, int command_delay,
@@ -498,7 +498,7 @@ irc_server_new (char *name, int autoconnect, int autoreconnect,
         new_server->autoconnect = autoconnect;
         new_server->autoreconnect = autoreconnect;
         new_server->autoreconnect_delay = autoreconnect_delay;
-        new_server->command_line = command_line;
+        new_server->temp_server = temp_server;
         new_server->address = strdup (address);
         new_server->port = port;
         new_server->ipv6 = ipv6;
@@ -527,8 +527,75 @@ irc_server_new (char *name, int autoconnect, int autoreconnect,
     return new_server;
 }
 
+/*
+ * irc_server_duplicate: duplicate a server
+ *                       return: pointer to new server, NULL if error
+ */
+
+t_irc_server *
+irc_server_duplicate (t_irc_server *server, char *new_name)
+{
+    t_irc_server *new_server;
+    
+    /* check if another server exists with this name */
+    if (irc_server_search (new_name))
+        return 0;
+    
+    /* duplicate server */
+    new_server = irc_server_new (new_name,
+                                 server->autoconnect,
+                                 server->autoreconnect,
+                                 server->autoreconnect_delay,
+                                 server->temp_server,
+                                 server->address,
+                                 server->port,
+                                 server->ipv6,
+                                 server->ssl,
+                                 server->password,
+                                 server->nick1,
+                                 server->nick2,
+                                 server->nick3,
+                                 server->username,
+                                 server->realname,
+                                 server->hostname,
+                                 server->command,
+                                 server->command_delay,
+                                 server->autojoin,
+                                 server->autorejoin,
+                                 server->notify_levels);
+    
+    return new_server;
+}
+
+/*
+ * irc_server_rename: rename server (internal name)
+ *                    return: 1 if ok, 0 if error
+ */
+
+int
+irc_server_rename (t_irc_server *server, char *new_name)
+{
+    char *str;
+    
+    /* check if another server exists with this name */
+    if (irc_server_search (new_name))
+        return 0;
+    
+    /* rename server */
+    str = strdup (new_name);
+    if (str)
+    {
+        if (server->name)
+            free (server->name);
+        server->name = str;
+        return 1;
+    }
+    return 0;
+}
+
 /*
  * irc_server_send: send data to IRC server
+ *                  return number of bytes sent, -1 if error
  */
 
 int
@@ -583,7 +650,7 @@ irc_server_outqueue_send (t_irc_server *server)
             if (irc_server_send (server, server->outqueue->message_after_mod,
                                  strlen (server->outqueue->message_after_mod)) <= 0)
             {
-                irc_display_prefix (server, server->buffer, PREFIX_ERROR);
+                irc_display_prefix (server, server->buffer, GUI_PREFIX_ERROR);
                 gui_printf (server->buffer, _("%s error sending data to IRC server\n"),
                             WEECHAT_ERROR);
             }
@@ -664,7 +731,7 @@ irc_server_send_one_msg (t_irc_server *server, char *message)
                     gui_printf_raw_data (server, 1, 1, ptr_msg);
                 if (irc_server_send (server, buffer, strlen (buffer)) <= 0)
                 {
-                    irc_display_prefix (server, server->buffer, PREFIX_ERROR);
+                    irc_display_prefix (server, server->buffer, GUI_PREFIX_ERROR);
                     gui_printf (server->buffer, _("%s error sending data to IRC server\n"),
                                 WEECHAT_ERROR);
                     rc = 0;
@@ -795,7 +862,7 @@ irc_server_msgq_add_msg (t_irc_server *server, char *msg)
     message = (t_irc_message *) malloc (sizeof (t_irc_message));
     if (!message)
     {
-        irc_display_prefix (server, server->buffer, PREFIX_ERROR);
+        irc_display_prefix (server, server->buffer, GUI_PREFIX_ERROR);
         gui_printf (server->buffer,
                     _("%s not enough memory for received IRC message\n"),
                     WEECHAT_ERROR);
@@ -808,7 +875,7 @@ irc_server_msgq_add_msg (t_irc_server *server, char *msg)
                                          strlen (msg) + 1);
         if (!message->data)
         {
-            irc_display_prefix (server, server->buffer, PREFIX_ERROR);
+            irc_display_prefix (server, server->buffer, GUI_PREFIX_ERROR);
             gui_printf (server->buffer,
                         _("%s not enough memory for received IRC message\n"),
                         WEECHAT_ERROR);
@@ -825,15 +892,15 @@ irc_server_msgq_add_msg (t_irc_server *server, char *msg)
         message->data = strdup (msg);
     message->next_message = NULL;
 
-    if (msgq_last_msg)
+    if (irc_msgq_last_msg)
     {
-        msgq_last_msg->next_message = message;
-        msgq_last_msg = message;
+        irc_msgq_last_msg->next_message = message;
+        irc_msgq_last_msg = message;
     }
     else
     {
-        recv_msgq = message;
-        msgq_last_msg = message;
+        irc_recv_msgq = message;
+        irc_msgq_last_msg = message;
     }
 }
 
@@ -855,7 +922,7 @@ irc_server_msgq_add_unterminated (t_irc_server *server, char *string)
                               strlen (string) + 1);
         if (!server->unterminated_message)
         {
-            irc_display_prefix (server, server->buffer, PREFIX_ERROR);
+            irc_display_prefix (server, server->buffer, GUI_PREFIX_ERROR);
             gui_printf (server->buffer,
                         _("%s not enough memory for received IRC message\n"),
                         WEECHAT_ERROR);
@@ -868,7 +935,7 @@ irc_server_msgq_add_unterminated (t_irc_server *server, char *string)
         server->unterminated_message = strdup (string);
         if (!server->unterminated_message)
         {
-            irc_display_prefix (server, server->buffer, PREFIX_ERROR);
+            irc_display_prefix (server, server->buffer, GUI_PREFIX_ERROR);
             gui_printf (server->buffer,
                         _("%s not enough memory for received IRC message\n"),
                         WEECHAT_ERROR);
@@ -925,26 +992,26 @@ irc_server_msgq_flush ()
     char *ptr_data, *new_msg, *ptr_msg, *pos;
     char *host, *command, *args;
     
-    while (recv_msgq)
+    while (irc_recv_msgq)
     {
-        if (recv_msgq->data)
+        if (irc_recv_msgq->data)
         {
 #ifdef DEBUG
-            gui_printf (gui_current_window->buffer, "[DEBUG] %s\n", recv_msgq->data);
+            gui_printf (gui_current_window->buffer, "[DEBUG] %s\n", irc_recv_msgq->data);
 #endif
-            ptr_data = recv_msgq->data;
+            ptr_data = irc_recv_msgq->data;
             while (ptr_data[0] == ' ')
                 ptr_data++;
             
             if (ptr_data[0])
             {
-                gui_printf_raw_data (recv_msgq->server, 0, 0, ptr_data);
+                gui_printf_raw_data (irc_recv_msgq->server, 0, 0, ptr_data);
 #ifdef DEBUG
                 gui_printf (NULL, "[DEBUG] data received from server: %s\n", ptr_data);
 #endif
 #ifdef PLUGINS
                 new_msg = plugin_modifier_exec (PLUGIN_MODIFIER_IRC_IN,
-                                                recv_msgq->server->name,
+                                                irc_recv_msgq->server->name,
                                                 ptr_data);
 #else
                 new_msg = NULL;
@@ -969,28 +1036,28 @@ irc_server_msgq_flush ()
                             pos[0] = '\0';
 
                         if (new_msg)
-                            gui_printf_raw_data (recv_msgq->server, 0, 1, ptr_msg);
+                            gui_printf_raw_data (irc_recv_msgq->server, 0, 1, ptr_msg);
                         
                         irc_server_parse_message (ptr_msg, &host, &command, &args);
                         
-                        switch (irc_recv_command (recv_msgq->server, ptr_msg, host, command, args))
+                        switch (irc_recv_command (irc_recv_msgq->server, ptr_msg, host, command, args))
                         {
                             case -1:
-                                irc_display_prefix (recv_msgq->server,
-                                                    recv_msgq->server->buffer, PREFIX_ERROR);
-                                gui_printf (recv_msgq->server->buffer,
+                                irc_display_prefix (irc_recv_msgq->server,
+                                                    irc_recv_msgq->server->buffer, GUI_PREFIX_ERROR);
+                                gui_printf (irc_recv_msgq->server->buffer,
                                             _("%s Command \"%s\" failed!\n"), WEECHAT_ERROR, command);
                                 break;
                             case -2:
-                                irc_display_prefix (recv_msgq->server,
-                                                    recv_msgq->server->buffer, PREFIX_ERROR);
-                                gui_printf (recv_msgq->server->buffer,
+                                irc_display_prefix (irc_recv_msgq->server,
+                                                    irc_recv_msgq->server->buffer, GUI_PREFIX_ERROR);
+                                gui_printf (irc_recv_msgq->server->buffer,
                                             _("%s No command to execute!\n"), WEECHAT_ERROR);
                                 break;
                             case -3:
-                                irc_display_prefix (recv_msgq->server,
-                                                    recv_msgq->server->buffer, PREFIX_ERROR);
-                                gui_printf (recv_msgq->server->buffer,
+                                irc_display_prefix (irc_recv_msgq->server,
+                                                    irc_recv_msgq->server->buffer, GUI_PREFIX_ERROR);
+                                gui_printf (irc_recv_msgq->server->buffer,
                                             _("%s Unknown command: cmd=\"%s\", host=\"%s\", args=\"%s\"\n"),
                                             WEECHAT_WARNING, command, host, args);
                                 break;
@@ -1012,18 +1079,18 @@ irc_server_msgq_flush ()
                     }
                 }
                 else
-                    gui_printf_raw_data (recv_msgq->server, 0, 1, _("(message dropped)"));
+                    gui_printf_raw_data (irc_recv_msgq->server, 0, 1, _("(message dropped)"));
                 if (new_msg)
                     free (new_msg);
             }
-            free (recv_msgq->data);
+            free (irc_recv_msgq->data);
         }
         
-        next = recv_msgq->next_message;
-        free (recv_msgq);
-        recv_msgq = next;
-        if (recv_msgq == NULL)
-            msgq_last_msg = NULL;
+        next = irc_recv_msgq->next_message;
+        free (irc_recv_msgq);
+        irc_recv_msgq = next;
+        if (irc_recv_msgq == NULL)
+            irc_msgq_last_msg = NULL;
     }
 }
 
@@ -1055,7 +1122,7 @@ irc_server_recv (t_irc_server *server)
     }
     else
     {
-        irc_display_prefix (server, server->buffer, PREFIX_ERROR);
+        irc_display_prefix (server, server->buffer, GUI_PREFIX_ERROR);
         gui_printf (server->buffer,
                     _("%s cannot read data from socket, disconnecting from server...\n"),
                     WEECHAT_ERROR);
@@ -1139,7 +1206,7 @@ irc_server_reconnect_schedule (t_irc_server *server)
     if (server->autoreconnect)
     {
         server->reconnect_start = time (NULL);
-        irc_display_prefix (server, server->buffer, PREFIX_INFO);
+        irc_display_prefix (server, server->buffer, GUI_PREFIX_INFO);
         gui_printf (server->buffer, _("%s: Reconnecting to server in %d seconds\n"),
                     PACKAGE_NAME, server->autoreconnect_delay);
     }
@@ -1172,7 +1239,7 @@ irc_server_child_read (t_irc_server *server)
                                               (gnutls_transport_ptr) ((unsigned long) server->sock));
                     if (gnutls_handshake (server->gnutls_sess) < 0)
                     {
-                        irc_display_prefix (server, server->buffer, PREFIX_ERROR);
+                        irc_display_prefix (server, server->buffer, GUI_PREFIX_ERROR);
                         gui_printf (server->buffer,
                                     _("%s gnutls handshake failed\n"),
                                     WEECHAT_ERROR);
@@ -1188,7 +1255,7 @@ irc_server_child_read (t_irc_server *server)
                 break;
             /* adress not found */
             case '1':
-                irc_display_prefix (server, server->buffer, PREFIX_ERROR);
+                irc_display_prefix (server, server->buffer, GUI_PREFIX_ERROR);
                 if (cfg_proxy_use)
                     gui_printf (server->buffer,
                                 _("%s proxy address \"%s\" not found\n"),
@@ -1202,7 +1269,7 @@ irc_server_child_read (t_irc_server *server)
                 break;
             /* IP address not found */
             case '2':
-                irc_display_prefix (server, server->buffer, PREFIX_ERROR);
+                irc_display_prefix (server, server->buffer, GUI_PREFIX_ERROR);
                 if (cfg_proxy_use)
                     gui_printf (server->buffer,
                                 _("%s proxy IP address not found\n"), WEECHAT_ERROR);
@@ -1214,7 +1281,7 @@ irc_server_child_read (t_irc_server *server)
                 break;
             /* connection refused */
             case '3':
-                irc_display_prefix (server, server->buffer, PREFIX_ERROR);
+                irc_display_prefix (server, server->buffer, GUI_PREFIX_ERROR);
                 if (cfg_proxy_use)
                     gui_printf (server->buffer,
                                 _("%s proxy connection refused\n"), WEECHAT_ERROR);
@@ -1226,7 +1293,7 @@ irc_server_child_read (t_irc_server *server)
                 break;
             /* proxy fails to connect to server */
             case '4':
-                irc_display_prefix (server, server->buffer, PREFIX_ERROR);
+                irc_display_prefix (server, server->buffer, GUI_PREFIX_ERROR);
                 gui_printf (server->buffer,
                             _("%s proxy fails to establish connection to "
                               "server (check username/password if used)\n"),
@@ -1236,7 +1303,7 @@ irc_server_child_read (t_irc_server *server)
                 break;
             /* fails to set local hostname/IP */
             case '5':
-                irc_display_prefix (server, server->buffer, PREFIX_ERROR);
+                irc_display_prefix (server, server->buffer, GUI_PREFIX_ERROR);
                 gui_printf (server->buffer,
                             _("%s unable to set local hostname/IP\n"),
                             WEECHAT_ERROR);
@@ -1744,22 +1811,24 @@ irc_server_child (t_irc_server *server)
  */
 
 int
-irc_server_connect (t_irc_server *server)
+irc_server_connect (t_irc_server *server, int disable_autojoin)
 {
     int child_pipe[2], set;
+#ifndef __CYGWIN__
     pid_t pid;
+#endif
     
 #ifndef HAVE_GNUTLS
     if (server->ssl)
     {
-        irc_display_prefix (server, server->buffer, PREFIX_ERROR);
+        irc_display_prefix (server, server->buffer, GUI_PREFIX_ERROR);
         gui_printf (server->buffer,
                     _("%s cannot connect with SSL since WeeChat was not built "
                     "with GNUtls support\n"), WEECHAT_ERROR);
         return 0;
     }
 #endif
-    irc_display_prefix (server, server->buffer, PREFIX_INFO);
+    irc_display_prefix (server, server->buffer, GUI_PREFIX_INFO);
     if (cfg_proxy_use)
       {
           gui_printf (server->buffer,
@@ -1799,7 +1868,7 @@ irc_server_connect (t_irc_server *server)
     {
         if (gnutls_init (&server->gnutls_sess, GNUTLS_CLIENT) != 0)
         {
-            irc_display_prefix (server, server->buffer, PREFIX_ERROR);
+            irc_display_prefix (server, server->buffer, GUI_PREFIX_ERROR);
             gui_printf (server->buffer,
                         _("%s gnutls init error\n"), WEECHAT_ERROR);
             return 0;
@@ -1815,7 +1884,7 @@ irc_server_connect (t_irc_server *server)
     /* create pipe for child process */
     if (pipe (child_pipe) < 0)
     {
-        irc_display_prefix (server, server->buffer, PREFIX_ERROR);
+        irc_display_prefix (server, server->buffer, GUI_PREFIX_ERROR);
         gui_printf (server->buffer,
                     _("%s cannot create pipe\n"), WEECHAT_ERROR);
         return 0;
@@ -1830,7 +1899,7 @@ irc_server_connect (t_irc_server *server)
       server->sock = socket ((server->ipv6) ? AF_INET6 : AF_INET, SOCK_STREAM, 0);
     if (server->sock == -1)
     {
-        irc_display_prefix (server, server->buffer, PREFIX_ERROR);
+        irc_display_prefix (server, server->buffer, GUI_PREFIX_ERROR);
         gui_printf (server->buffer,
                     _("%s cannot create socket\n"), WEECHAT_ERROR);
         return 0;
@@ -1841,7 +1910,7 @@ irc_server_connect (t_irc_server *server)
     if (setsockopt (server->sock, SOL_SOCKET, SO_REUSEADDR,
         (void *) &set, sizeof (set)) == -1)
     {
-        irc_display_prefix (server, server->buffer, PREFIX_ERROR);
+        irc_display_prefix (server, server->buffer, GUI_PREFIX_ERROR);
         gui_printf (server->buffer,
                     _("%s cannot set socket option \"SO_REUSEADDR\"\n"),
                     WEECHAT_WARNING);
@@ -1852,12 +1921,21 @@ irc_server_connect (t_irc_server *server)
     if (setsockopt (server->sock, SOL_SOCKET, SO_KEEPALIVE,
         (void *) &set, sizeof (set)) == -1)
     {
-        irc_display_prefix (server, server->buffer, PREFIX_ERROR);
+        irc_display_prefix (server, server->buffer, GUI_PREFIX_ERROR);
         gui_printf (server->buffer,
                     _("%s cannot set socket option \"SO_KEEPALIVE\"\n"),
                     WEECHAT_WARNING);
     }
-    
+
+#ifdef __CYGWIN__
+    /* connection may block under Cygwin, there's no other known way
+       to do better today, since connect() in child process seems not to work
+       any suggestion is welcome to improve that!
+    */
+    irc_server_child (server);
+    server->child_pid = 0;
+    irc_server_child_read (server);
+#else
     switch (pid = fork ())
     {
         /* fork failed */
@@ -1870,9 +1948,11 @@ irc_server_connect (t_irc_server *server)
             irc_server_child (server);
             _exit (EXIT_SUCCESS);
     }
-    
     /* parent process */
     server->child_pid = pid;
+#endif
+    
+    server->disable_autojoin = disable_autojoin;
     
     return 1;
 }
@@ -1884,12 +1964,12 @@ irc_server_connect (t_irc_server *server)
 void
 irc_server_reconnect (t_irc_server *server)
 {
-    irc_display_prefix (server, server->buffer, PREFIX_INFO);
+    irc_display_prefix (server, server->buffer, GUI_PREFIX_INFO);
     gui_printf (server->buffer, _("%s: Reconnecting to server...\n"),
                 PACKAGE_NAME);
     server->reconnect_start = 0;
     
-    if (irc_server_connect (server))
+    if (irc_server_connect (server, 0))
         server->reconnect_join = 1;
     else
         irc_server_reconnect_schedule (server);
@@ -1900,20 +1980,20 @@ irc_server_reconnect (t_irc_server *server)
  */
 
 void
-irc_server_auto_connect (int auto_connect, int command_line)
+irc_server_auto_connect (int auto_connect, int temp_server)
 {
     t_irc_server *ptr_server;
     
     for (ptr_server = irc_servers; ptr_server;
          ptr_server = ptr_server->next_server)
     {
-        if ( ((command_line) && (ptr_server->command_line))
-            || ((!command_line) && (auto_connect) && (ptr_server->autoconnect)) )
+        if ( ((temp_server) && (ptr_server->temp_server))
+            || ((!temp_server) && (auto_connect) && (ptr_server->autoconnect)) )
         {
             (void) gui_buffer_new (gui_current_window, ptr_server, NULL,
-                                   BUFFER_TYPE_STANDARD, 1);
+                                   GUI_BUFFER_TYPE_STANDARD, 1);
             gui_window_redraw_buffer (gui_current_window->buffer);
-            if (!irc_server_connect (ptr_server))
+            if (!irc_server_connect (ptr_server, 0))
                 irc_server_reconnect_schedule (ptr_server);
         }
     }
@@ -1935,7 +2015,7 @@ irc_server_disconnect (t_irc_server *server, int reconnect)
              ptr_channel = ptr_channel->next_channel)
         {
             irc_nick_free_all (ptr_channel);
-            irc_display_prefix (NULL, ptr_channel->buffer, PREFIX_INFO);
+            irc_display_prefix (NULL, ptr_channel->buffer, GUI_PREFIX_INFO);
             gui_printf (ptr_channel->buffer, _("Disconnected from server!\n"));
             gui_nicklist_draw (ptr_channel->buffer, 1, 1);
             gui_status_draw (ptr_channel->buffer, 1);
@@ -1946,7 +2026,7 @@ irc_server_disconnect (t_irc_server *server, int reconnect)
     
     if (server->buffer)
     {
-        irc_display_prefix (server, server->buffer, PREFIX_INFO);
+        irc_display_prefix (server, server->buffer, GUI_PREFIX_INFO);
         gui_printf (server->buffer, _("Disconnected from server!\n"));
     }
     
@@ -1995,6 +2075,43 @@ irc_server_disconnect_all ()
         irc_server_disconnect (ptr_server, 0);
 }
 
+/*
+ * irc_server_autojoin_channels: autojoin (or rejoin) channels
+ */
+
+void
+irc_server_autojoin_channels (t_irc_server *server)
+{
+    t_irc_channel *ptr_channel;
+    
+    /* auto-join after disconnection (only rejoins opened channels) */
+    if (!server->disable_autojoin && server->reconnect_join && server->channels)
+    {
+        for (ptr_channel = server->channels; ptr_channel;
+             ptr_channel = ptr_channel->next_channel)
+        {
+            if (ptr_channel->type == IRC_CHANNEL_TYPE_CHANNEL)
+            {
+                if (ptr_channel->key)
+                    irc_server_sendf (server, "JOIN %s %s",
+                                      ptr_channel->name, ptr_channel->key);
+                else
+                    irc_server_sendf (server, "JOIN %s",
+                                      ptr_channel->name);
+            }
+        }
+        server->reconnect_join = 0;
+    }
+    else
+    {
+        /* auto-join when connecting to server for first time */
+        if (!server->disable_autojoin && server->autojoin && server->autojoin[0])
+            irc_send_cmd_join (server, NULL, server->autojoin);
+    }
+
+    server->disable_autojoin = 0;
+}
+
 /*
  * irc_server_search: return pointer on a server with a name
  */
@@ -2081,6 +2198,46 @@ irc_server_name_already_exists (char *name)
     return 0;
 }
 
+/*
+ * irc_server_get_channel_count: return number of channels for server
+ */
+
+int
+irc_server_get_channel_count (t_irc_server *server)
+{
+    int count;
+    t_irc_channel *ptr_channel;
+    
+    count = 0;
+    for (ptr_channel = server->channels; ptr_channel;
+         ptr_channel = ptr_channel->next_channel)
+    {
+        if (ptr_channel->type == IRC_CHANNEL_TYPE_CHANNEL)
+        count++;
+    }
+    return count;
+}
+
+/*
+ * irc_server_get_pv_count: return number of pv for server
+ */
+
+int
+irc_server_get_pv_count (t_irc_server *server)
+{
+    int count;
+    t_irc_channel *ptr_channel;
+    
+    count = 0;
+    for (ptr_channel = server->channels; ptr_channel;
+         ptr_channel = ptr_channel->next_channel)
+    {
+        if (ptr_channel->type != IRC_CHANNEL_TYPE_CHANNEL)
+            count++;
+    }
+    return count;
+}
+
 /*
  * irc_server_remove_away: remove away for all chans/nicks (for all servers)
  */
@@ -2097,7 +2254,7 @@ irc_server_remove_away ()
         {
             for (ptr_channel = ptr_server->channels; ptr_channel; ptr_channel = ptr_channel->next_channel)
             {
-                if (ptr_channel->type == CHANNEL_TYPE_CHANNEL)
+                if (ptr_channel->type == IRC_CHANNEL_TYPE_CHANNEL)
                     irc_channel_remove_away (ptr_channel);
             }
         }
@@ -2120,7 +2277,7 @@ irc_server_check_away ()
         {
             for (ptr_channel = ptr_server->channels; ptr_channel; ptr_channel = ptr_channel->next_channel)
             {
-                if (ptr_channel->type == CHANNEL_TYPE_CHANNEL)
+                if (ptr_channel->type == IRC_CHANNEL_TYPE_CHANNEL)
                     irc_channel_check_away (ptr_server, ptr_channel, 0);
             }
         }
@@ -2140,7 +2297,7 @@ irc_server_set_away (t_irc_server *server, char *nick, int is_away)
     {
         if (server->is_connected)
         {
-            if (ptr_channel->type == CHANNEL_TYPE_CHANNEL)
+            if (ptr_channel->type == IRC_CHANNEL_TYPE_CHANNEL)
                 irc_channel_set_away (ptr_channel, nick, is_away);
         }
     }
@@ -2156,7 +2313,7 @@ irc_server_get_default_notify_level (t_irc_server *server)
     int notify, value;
     char *pos;
 
-    notify = NOTIFY_LEVEL_DEFAULT;
+    notify = GUI_NOTIFY_LEVEL_DEFAULT;
     
     if (!server || !server->notify_levels)
         return notify;
@@ -2168,7 +2325,8 @@ irc_server_get_default_notify_level (t_irc_server *server)
         if (pos[0])
         {
             value = (int)(pos[0] - '0');
-            if ((value >= NOTIFY_LEVEL_MIN) && (value <= NOTIFY_LEVEL_MAX))
+            if ((value >= GUI_NOTIFY_LEVEL_MIN)
+                && (value <= GUI_NOTIFY_LEVEL_MAX))
                 notify = value;
         }
     }
@@ -2204,7 +2362,7 @@ irc_server_print_log (t_irc_server *server)
     weechat_log_printf ("  autoconnect . . . . : %d\n",   server->autoconnect);
     weechat_log_printf ("  autoreconnect . . . : %d\n",   server->autoreconnect);
     weechat_log_printf ("  autoreconnect_delay : %d\n",   server->autoreconnect_delay);
-    weechat_log_printf ("  command_line. . . . : %d\n",   server->command_line);
+    weechat_log_printf ("  temp_server . . . . : %d\n",   server->temp_server);
     weechat_log_printf ("  address . . . . . . : '%s'\n", server->address);
     weechat_log_printf ("  port. . . . . . . . : %d\n",   server->port);
     weechat_log_printf ("  ipv6. . . . . . . . : %d\n",   server->ipv6);
@@ -2235,7 +2393,9 @@ irc_server_print_log (t_irc_server *server)
     weechat_log_printf ("  nick_modes. . . . . : '%s'\n", server->nick_modes);
     weechat_log_printf ("  prefix. . . . . . . : '%s'\n", server->prefix);
     weechat_log_printf ("  reconnect_start . . : %ld\n",  server->reconnect_start);
+    weechat_log_printf ("  command_time. . . . : %ld\n",  server->command_time);
     weechat_log_printf ("  reconnect_join. . . : %d\n",   server->reconnect_join);
+    weechat_log_printf ("  disable_autojoin. . : %d\n",   server->disable_autojoin);
     weechat_log_printf ("  is_away . . . . . . : %d\n",   server->is_away);
     weechat_log_printf ("  away_message. . . . : '%s'\n", server->away_message);
     weechat_log_printf ("  away_time . . . . . : %ld\n",  server->away_time);
