@@ -4,7 +4,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -40,31 +39,20 @@
 #define NI_MAXHOST 256
 #endif
 
-/* prefixes for chat window */
-
-#define PREFIX_SERVER    "-@-"
-#define PREFIX_INFO      "-=-"
-#define PREFIX_ACTION_ME "-*-"
-#define PREFIX_JOIN      "-->"
-#define PREFIX_PART      "<--"
-#define PREFIX_QUIT      "<--"
-#define PREFIX_ERROR     "=!="
-#define PREFIX_PLUGIN    "-P-"
-#define PREFIX_RECV_MOD  "==>"
-#define PREFIX_SEND_MOD  "<=="
-
-#define DEFAULT_IRC_PORT 6667
+#define IRC_DEFAULT_PORT 6667
+#define IRC_DEFAULT_PREFIXES_LIST "@%+~&!-"
 
 /* nick types */
 
-#define NICK_CHANOWNER  1
-#define NICK_CHANADMIN  2
-#define NICK_OP         4
-#define NICK_HALFOP     8
-#define NICK_VOICE      16
-#define NICK_AWAY       32
-#define NICK_CHANADMIN2 64
-#define NICK_SET_FLAG(nick, set, flag) \
+#define IRC_NICK_CHANOWNER  1
+#define IRC_NICK_CHANADMIN  2
+#define IRC_NICK_OP         4
+#define IRC_NICK_HALFOP     8
+#define IRC_NICK_VOICE      16
+#define IRC_NICK_AWAY       32
+#define IRC_NICK_CHANADMIN2 64
+#define IRC_NICK_CHANUSER   128
+#define IRC_NICK_SET_FLAG(nick, set, flag) \
     if (set) \
         nick->flags |= flag; \
     else \
@@ -91,15 +79,15 @@ struct t_irc_nick
     t_irc_nick *next_nick;          /* link to next nick on the channel       */
 };
 
-#define CHANNEL_PREFIX "#&+!"
+#define IRC_CHANNEL_PREFIX "#&+!"
 
 /* channel types */
-#define CHANNEL_TYPE_UNKNOWN  -1
-#define CHANNEL_TYPE_CHANNEL  0
-#define CHANNEL_TYPE_PRIVATE  1
-#define CHANNEL_TYPE_DCC_CHAT 2
+#define IRC_CHANNEL_TYPE_UNKNOWN  -1
+#define IRC_CHANNEL_TYPE_CHANNEL  0
+#define IRC_CHANNEL_TYPE_PRIVATE  1
+#define IRC_CHANNEL_TYPE_DCC_CHAT 2
 
-#define CHANNEL_NICKS_SPEAKING_LIMIT 32
+#define IRC_CHANNEL_NICKS_SPEAKING_LIMIT 32
 
 typedef struct t_irc_channel t_irc_channel;
 
@@ -147,11 +135,11 @@ typedef struct t_irc_server t_irc_server;
 struct t_irc_server
 {
     /* user choices */
-    char *name;                     /* name of server (only for display)      */
+    char *name;                     /* internal name of server                */
     int autoconnect;                /* = 1 if auto connect at startup         */
     int autoreconnect;              /* = 1 if auto reco when disconnected     */
     int autoreconnect_delay;        /* delay before trying again reconnect    */
-    int command_line;               /* server was given on command line       */
+    int temp_server;                /* server is temporary (will not be saved)*/
     char *address;                  /* address of server (IP or name)         */
     int port;                       /* port for server (6667 by default)      */
     int ipv6;                       /* use IPv6 protocol                      */
@@ -184,7 +172,10 @@ struct t_irc_server
     char *nick_modes;               /* nick modes                             */
     char *prefix;                   /* nick prefix allowed (from msg 005)     */
     time_t reconnect_start;         /* this time + delay = reconnect time     */
+    time_t command_time;            /* this time + command_delay = time to    */
+                                    /* autojoin channels                      */
     int reconnect_join;             /* 1 if channels opened to rejoin         */
+    int disable_autojoin;           /* 1 if user asked to not autojoin chans  */
     int is_away;                    /* 1 is user is marked as away            */
     char *away_message;             /* away message, NULL if not away         */
     time_t away_time;               /* time() when user marking as away       */
@@ -242,46 +233,51 @@ struct t_irc_message
 
 /* DCC types */
 
-#define DCC_CHAT_RECV            0  /* receiving DCC chat                     */
-#define DCC_CHAT_SEND            1  /* sending DCC chat                       */
-#define DCC_FILE_RECV            2  /* incoming DCC file                      */
-#define DCC_FILE_SEND            3  /* sending DCC file                       */
+#define IRC_DCC_CHAT_RECV        0  /* receiving DCC chat                     */
+#define IRC_DCC_CHAT_SEND        1  /* sending DCC chat                       */
+#define IRC_DCC_FILE_RECV        2  /* incoming DCC file                      */
+#define IRC_DCC_FILE_SEND        3  /* sending DCC file                       */
 
 /* DCC status */
 
-#define DCC_WAITING              0  /* waiting for host answer                */
-#define DCC_CONNECTING           1  /* connecting to host                     */
-#define DCC_ACTIVE               2  /* sending/receiving data                 */
-#define DCC_DONE                 3  /* transfer done                          */
-#define DCC_FAILED               4  /* DCC failed                             */
-#define DCC_ABORTED              5  /* DCC aborted by user                    */
+#define IRC_DCC_WAITING          0  /* waiting for host answer                */
+#define IRC_DCC_CONNECTING       1  /* connecting to host                     */
+#define IRC_DCC_ACTIVE           2  /* sending/receiving data                 */
+#define IRC_DCC_DONE             3  /* transfer done                          */
+#define IRC_DCC_FAILED           4  /* DCC failed                             */
+#define IRC_DCC_ABORTED          5  /* DCC aborted by user                    */
 
 /* DCC blocksize (for file) */
 
-#define DCC_MIN_BLOCKSIZE     1024  /* min DCC block size when sending file   */
-#define DCC_MAX_BLOCKSIZE   102400  /* max DCC block size when sending file   */
+#define IRC_DCC_MIN_BLOCKSIZE   1024  /* min DCC block size when sending file */
+#define IRC_DCC_MAX_BLOCKSIZE 102400  /* max DCC block size when sending file */
 
 /* DCC errors (for file) */
 
-#define DCC_NO_ERROR             0  /* used when no error to report, all ok!  */
-#define DCC_ERROR_READ_LOCAL     1  /* unable to read local file              */
-#define DCC_ERROR_SEND_BLOCK     2  /* unable to send block to receiver       */
-#define DCC_ERROR_READ_ACK       3  /* unable to read ACK from receiver       */
-#define DCC_ERROR_CONNECT_SENDER 4  /* unable to connect to sender            */
-#define DCC_ERROR_RECV_BLOCK     5  /* unable to receive block from sender    */
-#define DCC_ERROR_WRITE_LOCAL    6  /* unable to write to local file          */
+#define IRC_DCC_NO_ERROR             0  /* no error to report, all ok!        */
+#define IRC_DCC_ERROR_READ_LOCAL     1  /* unable to read local file          */
+#define IRC_DCC_ERROR_SEND_BLOCK     2  /* unable to send block to receiver   */
+#define IRC_DCC_ERROR_READ_ACK       3  /* unable to read ACK from receiver   */
+#define IRC_DCC_ERROR_CONNECT_SENDER 4  /* unable to connect to sender        */
+#define IRC_DCC_ERROR_RECV_BLOCK     5  /* unable to recv block from sender   */
+#define IRC_DCC_ERROR_WRITE_LOCAL    6  /* unable to write to local file      */
 
 /* DCC macros for type */
 
-#define DCC_IS_CHAT(type) ((type == DCC_CHAT_RECV) || (type == DCC_CHAT_SEND))
-#define DCC_IS_FILE(type) ((type == DCC_FILE_RECV) || (type == DCC_FILE_SEND))
-#define DCC_IS_RECV(type) ((type == DCC_CHAT_RECV) || (type == DCC_FILE_RECV))
-#define DCC_IS_SEND(type) ((type == DCC_CHAT_SEND) || (type == DCC_FILE_SEND))
+#define IRC_DCC_IS_CHAT(type) ((type == IRC_DCC_CHAT_RECV) || \
+                               (type == IRC_DCC_CHAT_SEND))
+#define IRC_DCC_IS_FILE(type) ((type == IRC_DCC_FILE_RECV) || \
+                               (type == IRC_DCC_FILE_SEND))
+#define IRC_DCC_IS_RECV(type) ((type == IRC_DCC_CHAT_RECV) || \
+                               (type == IRC_DCC_FILE_RECV))
+#define IRC_DCC_IS_SEND(type) ((type == IRC_DCC_CHAT_SEND) || \
+                               (type == IRC_DCC_FILE_SEND))
 
 /* DCC macro for status */
 
-#define DCC_ENDED(status) ((status == DCC_DONE) || (status == DCC_FAILED) || \
-                          (status == DCC_ABORTED))
+#define IRC_DCC_ENDED(status) ((status == IRC_DCC_DONE) || \
+                               (status == IRC_DCC_FAILED) || \
+                               (status == IRC_DCC_ABORTED))
 
 typedef struct t_irc_dcc t_irc_dcc;
 
@@ -325,10 +321,10 @@ struct t_irc_dcc
 /* pre-defined ignore types, all other types are made with IRC commands */
 /* for example:  part  join  quit  notice  invite  ...                  */
 
-#define IGNORE_ACTION  "action"
-#define IGNORE_CTCP    "ctcp"
-#define IGNORE_DCC     "dcc"
-#define IGNORE_PRIVATE "pv"
+#define IRC_IGNORE_ACTION  "action"
+#define IRC_IGNORE_CTCP    "ctcp"
+#define IRC_IGNORE_DCC     "dcc"
+#define IRC_IGNORE_PRIVATE "pv"
 
 typedef struct t_irc_ignore t_irc_ignore;
 
@@ -350,14 +346,11 @@ extern t_irc_server *irc_servers;
 extern const int gnutls_cert_type_prio[];
 extern const int gnutls_prot_prio[];
 #endif
-extern t_irc_message *recv_msgq, *msgq_last_msg;
-extern int check_away;
-extern t_irc_dcc *dcc_list;
-extern t_irc_dcc *last_dcc;
-extern char *dcc_status_string[6];
-extern char *channel_modes;
-extern char *nick_modes;
-extern char *ignore_types[];
+extern t_irc_message *irc_recv_msgq, *irc_msgq_last_msg;
+extern int irc_check_away;
+extern t_irc_dcc *irc_dcc_list;
+extern t_irc_dcc *irc_last_dcc;
+extern char *irc_dcc_status_string[6];
 extern t_irc_ignore *irc_ignore;
 extern t_irc_ignore *irc_last_ignore;
 
@@ -373,9 +366,8 @@ extern void irc_server_free_all ();
 extern t_irc_server *irc_server_new (char *, int, int, int, int, char *, int, int, int,
                                      char *, char *, char *, char *, char *, char *,
                                      char *, char *, int, char *, int, char *);
-extern char *irc_server_get_charset_decode_iso (t_irc_server *);
-extern char *irc_server_get_charset_decode_utf (t_irc_server *);
-extern char *irc_server_get_charset_encode (t_irc_server *);
+extern t_irc_server *irc_server_duplicate (t_irc_server *, char *);
+extern int irc_server_rename (t_irc_server *, char *);
 extern int irc_server_send (t_irc_server *, char *, int);
 extern void irc_server_outqueue_send (t_irc_server *);
 extern void irc_server_sendf (t_irc_server *, char *, ...);
@@ -389,15 +381,18 @@ extern int irc_server_resolve (char *, char *, int *);
 extern int irc_server_pass_socks4proxy (int, char*, int, char*);
 extern int irc_server_pass_socks5proxy (int, char*, int);
 extern int irc_server_pass_proxy (int, char*, int, char*);
-extern int irc_server_connect (t_irc_server *);
+extern int irc_server_connect (t_irc_server *, int);
 extern void irc_server_reconnect (t_irc_server *);
 extern void irc_server_auto_connect (int, int);
 extern void irc_server_disconnect (t_irc_server *, int);
 extern void irc_server_disconnect_all ();
+extern void irc_server_autojoin_channels ();
 extern t_irc_server *irc_server_search (char *);
 extern int irc_server_get_number_connected ();
 extern void irc_server_get_number_buffer (t_irc_server *, int *, int *);
 extern int irc_server_name_already_exists (char *);
+extern int irc_server_get_channel_count (t_irc_server *);
+extern int irc_server_get_pv_count (t_irc_server *);
 extern void irc_server_remove_away ();
 extern void irc_server_check_away ();
 extern void irc_server_set_away (t_irc_server *, char *, int);
@@ -428,7 +423,7 @@ extern void irc_channel_print_log (t_irc_channel *);
 
 extern int irc_nick_find_color (t_irc_nick *);
 extern t_irc_nick *irc_nick_new (t_irc_server *, t_irc_channel *, char *,
-                                 int, int, int, int, int, int);
+                                 int, int, int, int, int, int, int);
 extern void irc_nick_resort (t_irc_channel *, t_irc_nick *);
 extern void irc_nick_change (t_irc_channel *, t_irc_nick *, char *);
 extern void irc_nick_free (t_irc_channel *, t_irc_nick *);
@@ -441,7 +436,7 @@ extern void irc_nick_print_log (t_irc_nick *);
 
 /* mode functions (irc-mode.c) */
 
-extern void irc_mode_channel_set (t_irc_channel *, char *);
+extern void irc_mode_channel_set (t_irc_server *, t_irc_channel *, char *);
 extern void irc_mode_user_set (t_irc_server *, char *);
 extern int irc_mode_nick_prefix_allowed (t_irc_server *, char);
 
@@ -474,7 +469,7 @@ extern void irc_display_nick (t_gui_buffer *, t_irc_nick *, char *, int,
 extern void irc_display_away (t_irc_server *, char *, char *);
 extern void irc_display_mode (t_irc_server *, t_gui_buffer *, char *, char *,
                               char, char *, char *, char *, char *);
-extern void irc_display_server (t_irc_server *ptr_server);
+extern void irc_display_server (t_irc_server *ptr_server, int);
 
 /* IRC commands issued by user (irc-send.c) */
 
