@@ -4,7 +4,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /* plugins-interface.c: WeeChat plugins interface */
@@ -166,7 +165,7 @@ weechat_plugin_print (t_weechat_plugin *plugin,
     t_gui_buffer *ptr_buffer;
     va_list argptr;
     static char buf[8192];
-    char *buf2, *buf3;
+    char *buf2;
     
     if (!plugin || !message)
         return;
@@ -177,14 +176,10 @@ weechat_plugin_print (t_weechat_plugin *plugin,
     va_end (argptr);
 
     buf2 = weechat_iconv_to_internal (plugin->charset, buf);
-    buf3 = (char *)gui_color_decode ((unsigned char *)((buf2) ? buf2 : buf),
-                                     cfg_irc_colors_receive);
-    irc_display_prefix (NULL, ptr_buffer, PREFIX_PLUGIN);
-    gui_printf (ptr_buffer, "%s\n", (buf3) ? buf3 : ((buf2) ? buf2 : buf));
+    irc_display_prefix (NULL, ptr_buffer, GUI_PREFIX_PLUGIN);
+    gui_printf_keep_colors (ptr_buffer, "%s\n", (buf2) ? buf2 : buf);
     if (buf2)
         free (buf2);
-    if (buf3)
-        free (buf3);
 }
 
 /*
@@ -196,7 +191,7 @@ weechat_plugin_print_server (t_weechat_plugin *plugin, char *message, ...)
 {
     va_list argptr;
     static char buf[8192];
-    char *buf2, *buf3;
+    char *buf2;
     
     if (!plugin || !message)
         return;
@@ -206,14 +201,10 @@ weechat_plugin_print_server (t_weechat_plugin *plugin, char *message, ...)
     va_end (argptr);
 
     buf2 = weechat_iconv_to_internal (plugin->charset, buf);
-    buf3 = (char *)gui_color_decode ((unsigned char *)((buf2) ? buf2 : buf),
-                                     cfg_irc_colors_receive);
-    irc_display_prefix (NULL, NULL, PREFIX_PLUGIN);
-    gui_printf (NULL, "%s\n", (buf3) ? buf3 : ((buf2) ? buf2 : buf));
+    irc_display_prefix (NULL, NULL, GUI_PREFIX_PLUGIN);
+    gui_printf_keep_colors (NULL, "%s\n", (buf2) ? buf2 : buf);
     if (buf2)
         free (buf2);
-    if (buf3)
-        free (buf3);
 }
 
 /*
@@ -235,7 +226,7 @@ weechat_plugin_print_infobar (t_weechat_plugin *plugin, int time_displayed, char
     va_end (argptr);
     
     buf2 = weechat_iconv_to_internal (plugin->charset, buf);
-    gui_infobar_printf (time_displayed, COLOR_WIN_INFOBAR, "%s",
+    gui_infobar_printf (time_displayed, GUI_COLOR_WIN_INFOBAR, "%s",
                         (buf2) ? buf2 : buf);
     if (buf2)
         free (buf2);
@@ -460,7 +451,7 @@ weechat_plugin_exec_command (t_weechat_plugin *plugin,
     
     if (plugin_find_server_channel (server, channel, &ptr_server, &ptr_channel) < 0)
     {
-        irc_display_prefix (NULL, NULL, PREFIX_ERROR);
+        irc_display_prefix (NULL, NULL, GUI_PREFIX_ERROR);
         gui_printf (NULL,
                     _("%s server/channel (%s/%s) not found for plugin "
                       "exec command\n"),
@@ -586,9 +577,9 @@ weechat_plugin_get_info (t_weechat_plugin *plugin, char *info, char *server)
     }
     else if (ascii_strcasecmp (info, "channel") == 0)
     {
-        if (BUFFER_IS_CHANNEL(gui_current_window->buffer)
-            || BUFFER_IS_PRIVATE(gui_current_window->buffer))
-            return strdup (CHANNEL(gui_current_window->buffer)->name);
+        if (GUI_BUFFER_IS_CHANNEL(gui_current_window->buffer)
+            || GUI_BUFFER_IS_PRIVATE(gui_current_window->buffer))
+            return strdup (GUI_CHANNEL(gui_current_window->buffer)->name);
     }
     else if (ascii_strcasecmp (info, "server") == 0)
     {
@@ -631,11 +622,11 @@ weechat_plugin_get_dcc_info (t_weechat_plugin *plugin)
     if (!plugin)
         return NULL;
     
-    if (dcc_list)
+    if (irc_dcc_list)
     {
         dcc_info = NULL;
         last_dcc_info = NULL;
-        for (ptr_dcc = dcc_list; ptr_dcc; ptr_dcc = ptr_dcc->next_dcc)
+        for (ptr_dcc = irc_dcc_list; ptr_dcc; ptr_dcc = ptr_dcc->next_dcc)
         {
             new_dcc_info = (t_plugin_dcc_info *)malloc (sizeof (t_plugin_dcc_info));
             if (new_dcc_info)
@@ -925,7 +916,7 @@ weechat_plugin_get_server_info (t_weechat_plugin *plugin)
 		new_server_info->autoconnect = ptr_server->autoconnect;
 		new_server_info->autoreconnect = ptr_server->autoreconnect;
 		new_server_info->autoreconnect_delay = ptr_server->autoreconnect_delay;
-		new_server_info->command_line = ptr_server->command_line;
+		new_server_info->temp_server = ptr_server->temp_server;
 		new_server_info->address = (ptr_server->address) ? strdup (ptr_server->address) : strdup ("");
 		new_server_info->port = ptr_server->port;
 		new_server_info->ipv6 = ptr_server->ipv6;
@@ -1255,7 +1246,7 @@ t_plugin_window_info *
 weechat_plugin_get_window_info (t_weechat_plugin *plugin)
 {
     t_plugin_window_info *window_info, *last_window_info, *new_window_info;
-    t_gui_window *ptr_window;
+    t_gui_window *ptr_win;
 
     if (!plugin)
 	return NULL;
@@ -1264,18 +1255,18 @@ weechat_plugin_get_window_info (t_weechat_plugin *plugin)
     {
 	window_info = NULL;
 	last_window_info = NULL;
-	for (ptr_window = gui_windows; ptr_window; ptr_window = ptr_window->next_window)
+	for (ptr_win = gui_windows; ptr_win; ptr_win = ptr_win->next_window)
 	{
 	    new_window_info = (t_plugin_window_info *) malloc (sizeof (t_plugin_window_info));
 	    if (new_window_info)
 	    {
-                new_window_info->win_x = ptr_window->win_x;
-                new_window_info->win_y = ptr_window->win_y;
-                new_window_info->win_width = ptr_window->win_width;
-                new_window_info->win_height = ptr_window->win_height;
-                new_window_info->win_width_pct = ptr_window->win_width_pct;
-                new_window_info->win_height_pct = ptr_window->win_height_pct;
-                new_window_info->num_buffer = (ptr_window->buffer) ? ptr_window->buffer->number : 0;
+                new_window_info->win_x = ptr_win->win_x;
+                new_window_info->win_y = ptr_win->win_y;
+                new_window_info->win_width = ptr_win->win_width;
+                new_window_info->win_height = ptr_win->win_height;
+                new_window_info->win_width_pct = ptr_win->win_width_pct;
+                new_window_info->win_height_pct = ptr_win->win_height_pct;
+                new_window_info->num_buffer = (ptr_win->buffer) ? ptr_win->buffer->number : 0;
                 
 		new_window_info->prev_window = last_window_info;
                 new_window_info->next_window = NULL;
@@ -1340,8 +1331,8 @@ weechat_plugin_get_buffer_info (t_weechat_plugin *plugin)
                 new_buffer_info->type = ptr_buffer->type;
                 new_buffer_info->number = ptr_buffer->number;
                 new_buffer_info->num_displayed = ptr_buffer->num_displayed;
-                new_buffer_info->server_name = (SERVER(ptr_buffer)) ? strdup (SERVER(ptr_buffer)->name) : NULL;
-                new_buffer_info->channel_name = (CHANNEL(ptr_buffer)) ? strdup (CHANNEL(ptr_buffer)->name) : NULL;
+                new_buffer_info->server_name = (GUI_SERVER(ptr_buffer)) ? strdup (GUI_SERVER(ptr_buffer)->name) : NULL;
+                new_buffer_info->channel_name = (GUI_CHANNEL(ptr_buffer)) ? strdup (GUI_CHANNEL(ptr_buffer)->name) : NULL;
                 new_buffer_info->notify_level = ptr_buffer->notify_level;
                 new_buffer_info->log_filename = (ptr_buffer->log_filename) ? strdup (ptr_buffer->log_filename) : NULL;
                 
@@ -1421,7 +1412,7 @@ weechat_plugin_get_buffer_data (t_weechat_plugin *plugin, char *server, char *ch
             new_buffer_line->nick = (ptr_line->nick) ? strdup (ptr_line->nick) : NULL;
             if (ptr_line->data)
             {
-                data1 = (char *) gui_color_decode ((unsigned char *)(ptr_line->data + ptr_line->ofs_start_message), 0);
+                data1 = (char *) gui_color_decode ((unsigned char *)(ptr_line->data + ptr_line->ofs_start_message), 0, 0);
                 data2 = (data1) ? weechat_iconv_from_internal (plugin->charset, data1) : NULL;
                 if (data2)
                     new_buffer_line->data = data2;
