@@ -4,7 +4,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /* plugins.c: manages WeeChat plugins (dynamic C libraries) */
@@ -38,6 +37,7 @@
 #include "plugins.h"
 #include "plugins-config.h"
 #include "../common/command.h"
+#include "../common/log.h"
 #include "../common/util.h"
 #include "../common/weeconfig.h"
 #include "../irc/irc.h"
@@ -81,10 +81,10 @@ plugin_find_server_channel (char *server, char *channel,
     /* nothing given => return current server/channel */
     if ((!server || !server[0]) && (!channel || !channel[0]))
     {
-        (*ptr_server) = SERVER(gui_current_window->buffer);
-        (*ptr_channel) = (BUFFER_IS_CHANNEL(gui_current_window->buffer) ||
-                          BUFFER_IS_PRIVATE(gui_current_window->buffer)) ?
-            CHANNEL(gui_current_window->buffer) : NULL;
+        (*ptr_server) = GUI_SERVER(gui_current_window->buffer);
+        (*ptr_channel) = (GUI_BUFFER_IS_CHANNEL(gui_current_window->buffer) ||
+                          GUI_BUFFER_IS_PRIVATE(gui_current_window->buffer)) ?
+            GUI_CHANNEL(gui_current_window->buffer) : NULL;
     }
     else
     {
@@ -96,9 +96,9 @@ plugin_find_server_channel (char *server, char *channel,
         }
         else
         {
-            (*ptr_server) = SERVER(gui_current_window->buffer);
+            (*ptr_server) = GUI_SERVER(gui_current_window->buffer);
             if (!(*ptr_server))
-                (*ptr_server) = SERVER(gui_buffers);
+                (*ptr_server) = GUI_SERVER(gui_buffers);
         }
         
         if (channel && channel[0])
@@ -238,7 +238,7 @@ plugin_msg_handler_add (t_weechat_plugin *plugin, char *irc_command,
     }
     else
     {
-        irc_display_prefix (NULL, NULL, PREFIX_ERROR);
+        irc_display_prefix (NULL, NULL, GUI_PREFIX_ERROR);
         gui_printf (NULL,
                     _("%s plugin %s: unable to add handler for IRC command \"%s\" (not enough memory)\n"),
                     WEECHAT_ERROR, plugin->name, irc_command);
@@ -275,7 +275,7 @@ plugin_cmd_handler_add (t_weechat_plugin *plugin, char *command,
     
     if (plugin_cmd_handler_search (command))
     {
-        irc_display_prefix (NULL, NULL, PREFIX_ERROR);
+        irc_display_prefix (NULL, NULL, GUI_PREFIX_ERROR);
         gui_printf (NULL,
                     _("%s plugin %s: unable to add handler for \"%s\" command "
                       "(already exists)\n"),
@@ -285,7 +285,7 @@ plugin_cmd_handler_add (t_weechat_plugin *plugin, char *command,
     
     if (ascii_strcasecmp (command, "builtin") == 0)
     {
-        irc_display_prefix (NULL, NULL, PREFIX_ERROR);
+        irc_display_prefix (NULL, NULL, GUI_PREFIX_ERROR);
         gui_printf (NULL,
                     _("%s plugin %s: unable to add handler for \"%s\" command "
                       "(forbidden)\n"),
@@ -327,7 +327,7 @@ plugin_cmd_handler_add (t_weechat_plugin *plugin, char *command,
     }
     else
     {
-        irc_display_prefix (NULL, NULL, PREFIX_ERROR);
+        irc_display_prefix (NULL, NULL, GUI_PREFIX_ERROR);
         gui_printf (NULL,
                     _("%s plugin %s: unable to add handler for \"%s\" command (not enough memory)\n"),
                     WEECHAT_ERROR, plugin->name, command);
@@ -384,7 +384,7 @@ plugin_timer_handler_add (t_weechat_plugin *plugin, int interval,
     }
     else
     {
-        irc_display_prefix (NULL, NULL, PREFIX_ERROR);
+        irc_display_prefix (NULL, NULL, GUI_PREFIX_ERROR);
         gui_printf (NULL,
                     _("%s plugin %s: unable to add timer handler (not enough memory)\n"),
                     WEECHAT_ERROR, plugin->name);
@@ -440,7 +440,7 @@ plugin_keyboard_handler_add (t_weechat_plugin *plugin,
     }
     else
     {
-        irc_display_prefix (NULL, NULL, PREFIX_ERROR);
+        irc_display_prefix (NULL, NULL, GUI_PREFIX_ERROR);
         gui_printf (NULL,
                     _("%s plugin %s: unable to add keyboard handler (not enough memory)\n"),
                     WEECHAT_ERROR, plugin->name);
@@ -497,7 +497,7 @@ plugin_event_handler_add (t_weechat_plugin *plugin, char *event,
     }
     else
     {
-        irc_display_prefix (NULL, NULL, PREFIX_ERROR);
+        irc_display_prefix (NULL, NULL, GUI_PREFIX_ERROR);
         gui_printf (NULL,
                     _("%s plugin %s: unable to add event handler (not enough memory)\n"),
                     WEECHAT_ERROR, plugin->name);
@@ -697,14 +697,11 @@ plugin_keyboard_handler_exec (char *key, char *input_before, char *input_after)
  */
 
 int
-plugin_event_handler_exec (char *event, char *data)
+plugin_event_handler_exec (char *event, int argc, char **argv)
 {
     t_weechat_plugin *ptr_plugin;
     t_plugin_handler *ptr_handler;
     int return_code, final_return_code;
-    char *argv[1] = { NULL };
-    
-    argv[0] = data;
     
     final_return_code = PLUGIN_RC_OK;
     
@@ -718,7 +715,7 @@ plugin_event_handler_exec (char *event, char *data)
                 && (ascii_strcasecmp (ptr_handler->event, event) == 0))
             {
                 return_code = ((int) (ptr_handler->handler) (ptr_plugin,
-                                                             1, argv,
+                                                             argc, argv,
                                                              ptr_handler->handler_args,
                                                              ptr_handler->handler_pointer));
                 if (return_code == PLUGIN_RC_KO)
@@ -824,7 +821,8 @@ plugin_modifier_add (t_weechat_plugin *plugin, char *type, char *command,
     if (new_modifier)
     {
         new_modifier->type = type_int;
-        new_modifier->command = (command) ? strdup (command) : strdup ("*");
+        new_modifier->command = (command && command[0]) ?
+            strdup (command) : strdup ("*");
         new_modifier->modifier = modifier_func;
         new_modifier->modifier_args = (modifier_args) ? strdup (modifier_args) : NULL;
         new_modifier->modifier_pointer = modifier_pointer;
@@ -841,7 +839,7 @@ plugin_modifier_add (t_weechat_plugin *plugin, char *type, char *command,
     }
     else
     {
-        irc_display_prefix (NULL, NULL, PREFIX_ERROR);
+        irc_display_prefix (NULL, NULL, GUI_PREFIX_ERROR);
         gui_printf (NULL,
                     _("%s plugin %s: unable to add modifier (not enough memory)\n"),
                     WEECHAT_ERROR, plugin->name);
@@ -1074,7 +1072,7 @@ plugin_load (char *filename)
     handle = dlopen (full_name, RTLD_GLOBAL | RTLD_NOW);
     if (!handle)
     {
-        irc_display_prefix (NULL, NULL, PREFIX_ERROR);
+        irc_display_prefix (NULL, NULL, GUI_PREFIX_ERROR);
         gui_printf (NULL, _("%s unable to load plugin \"%s\": %s\n"),
                     WEECHAT_ERROR, full_name, dlerror());
         free (full_name);
@@ -1085,7 +1083,7 @@ plugin_load (char *filename)
     if (!name)
     {
         dlclose (handle);
-        irc_display_prefix (NULL, NULL, PREFIX_ERROR);
+        irc_display_prefix (NULL, NULL, GUI_PREFIX_ERROR);
         gui_printf (NULL, _("%s symbol \"plugin_name\" not found in plugin \"%s\", failed to load\n"),
                     WEECHAT_ERROR, full_name);
         free (full_name);
@@ -1095,7 +1093,7 @@ plugin_load (char *filename)
     if (plugin_search (name))
     {
         dlclose (handle);
-        irc_display_prefix (NULL, NULL, PREFIX_ERROR);
+        irc_display_prefix (NULL, NULL, GUI_PREFIX_ERROR);
         gui_printf (NULL,
                     _("%s unable to load plugin \"%s\": a plugin with "
                       "same name already exists\n"),
@@ -1108,7 +1106,7 @@ plugin_load (char *filename)
     if (!description)
     {
         dlclose (handle);
-        irc_display_prefix (NULL, NULL, PREFIX_ERROR);
+        irc_display_prefix (NULL, NULL, GUI_PREFIX_ERROR);
         gui_printf (NULL, _("%s symbol \"plugin_description\" not found in plugin \"%s\", failed to load\n"),
                     WEECHAT_ERROR, full_name);
         free (full_name);
@@ -1119,7 +1117,7 @@ plugin_load (char *filename)
     if (!version)
     {
         dlclose (handle);
-        irc_display_prefix (NULL, NULL, PREFIX_ERROR);
+        irc_display_prefix (NULL, NULL, GUI_PREFIX_ERROR);
         gui_printf (NULL, _("%s symbol \"plugin_version\" not found in plugin \"%s\", failed to load\n"),
                     WEECHAT_ERROR, full_name);
         free (full_name);
@@ -1132,7 +1130,7 @@ plugin_load (char *filename)
     if (!init_func)
     {
         dlclose (handle);
-        irc_display_prefix (NULL, NULL, PREFIX_ERROR);
+        irc_display_prefix (NULL, NULL, GUI_PREFIX_ERROR);
         gui_printf (NULL, _("%s function \"weechat_plugin_init\" not found in plugin \"%s\", failed to load\n"),
                     WEECHAT_ERROR, full_name);
         free (full_name);
@@ -1215,7 +1213,7 @@ plugin_load (char *filename)
             weechat_plugins = new_plugin;
         last_weechat_plugin = new_plugin;
         
-        irc_display_prefix (NULL, NULL, PREFIX_PLUGIN);
+        irc_display_prefix (NULL, NULL, GUI_PREFIX_PLUGIN);
         gui_printf (NULL,
                     _("Initializing plugin \"%s\" %s\n"),
                     new_plugin->name, new_plugin->version);
@@ -1223,7 +1221,7 @@ plugin_load (char *filename)
         /* init plugin */
         if (((t_weechat_init_func *)init_func) (new_plugin) < 0)
         {
-            irc_display_prefix (NULL, NULL, PREFIX_ERROR);
+            irc_display_prefix (NULL, NULL, GUI_PREFIX_ERROR);
             gui_printf (NULL,
                         _("%s unable to initialize plugin \"%s\"\n"),
                         WEECHAT_ERROR, full_name);
@@ -1234,7 +1232,7 @@ plugin_load (char *filename)
     }
     else
     {
-        irc_display_prefix (NULL, NULL, PREFIX_ERROR);
+        irc_display_prefix (NULL, NULL, GUI_PREFIX_ERROR);
         gui_printf (NULL,
                     _("%s unable to load plugin \"%s\" (not enough memory)\n"),
                     WEECHAT_ERROR, full_name);
@@ -1242,7 +1240,7 @@ plugin_load (char *filename)
         return NULL;
     }
     
-    irc_display_prefix (NULL, NULL, PREFIX_PLUGIN);
+    irc_display_prefix (NULL, NULL, GUI_PREFIX_PLUGIN);
     gui_printf (NULL,
                 _("Plugin \"%s\" (%s) loaded.\n"),
                 name, full_name);
@@ -1417,12 +1415,12 @@ plugin_unload_name (char *name)
     if (ptr_plugin)
     {
         plugin_unload (ptr_plugin);
-        irc_display_prefix (NULL, NULL, PREFIX_PLUGIN);
+        irc_display_prefix (NULL, NULL, GUI_PREFIX_PLUGIN);
         gui_printf (NULL, _("Plugin \"%s\" unloaded.\n"), name);
     }
     else
     {
-        irc_display_prefix (NULL, NULL, PREFIX_ERROR);
+        irc_display_prefix (NULL, NULL, GUI_PREFIX_ERROR);
         gui_printf (NULL,
                     _("%s plugin \"%s\" not found\n"),
                     WEECHAT_ERROR, name);
@@ -1457,7 +1455,7 @@ plugin_reload_name (char *name)
         if (filename)
         {
             plugin_unload (ptr_plugin);
-            irc_display_prefix (NULL, NULL, PREFIX_PLUGIN);
+            irc_display_prefix (NULL, NULL, GUI_PREFIX_PLUGIN);
             gui_printf (NULL, _("Plugin \"%s\" unloaded.\n"), name);
             plugin_load (filename);
             free (filename);
@@ -1465,7 +1463,7 @@ plugin_reload_name (char *name)
     }
     else
     {
-        irc_display_prefix (NULL, NULL, PREFIX_ERROR);
+        irc_display_prefix (NULL, NULL, GUI_PREFIX_ERROR);
         gui_printf (NULL,
                     _("%s plugin \"%s\" not found\n"),
                     WEECHAT_ERROR, name);
@@ -1500,3 +1498,69 @@ plugin_end ()
     /* unload all plugins */
     plugin_unload_all ();
 }
+
+/*
+ * plugin_print_log: print plugin infos in log (usually for crash dump)
+ */
+
+void
+plugin_print_log (t_weechat_plugin *plugin)
+{
+    t_plugin_handler *ptr_handler;
+    t_plugin_modifier *ptr_modifier;
+    
+    weechat_log_printf ("[plugin (addr:0x%X)]\n", plugin);
+    weechat_log_printf ("  filename . . . . . . . : '%s'\n", plugin->filename);
+    weechat_log_printf ("  handle . . . . . . . . : 0x%X\n", plugin->handle);
+    weechat_log_printf ("  name . . . . . . . . . : '%s'\n", plugin->name);
+    weechat_log_printf ("  description. . . . . . : '%s'\n", plugin->description);
+    weechat_log_printf ("  version. . . . . . . . : '%s'\n", plugin->version);
+    weechat_log_printf ("  charset. . . . . . . . : '%s'\n", plugin->charset);
+    weechat_log_printf ("  handlers . . . . . . . : 0x%X\n", plugin->handlers);
+    weechat_log_printf ("  last_handler . . . . . : 0x%X\n", plugin->last_handler);
+    weechat_log_printf ("  modifiers. . . . . . . : 0x%X\n", plugin->modifiers);
+    weechat_log_printf ("  last_modifier. . . . . : 0x%X\n", plugin->last_modifier);
+    weechat_log_printf ("  prev_plugin. . . . . . : 0x%X\n", plugin->prev_plugin);
+    weechat_log_printf ("  next_plugin. . . . . . : 0x%X\n", plugin->next_plugin);
+    
+    weechat_log_printf ("\n");
+    weechat_log_printf ("  => handlers:\n");
+    for (ptr_handler = plugin->handlers; ptr_handler;
+         ptr_handler = ptr_handler->next_handler)
+    {
+        weechat_log_printf ("\n");
+        weechat_log_printf ("       [handler (addr:0x%X)]\n", ptr_handler);
+        weechat_log_printf ("         type . . . . . . . . : %d\n",   ptr_handler->type);
+        weechat_log_printf ("         irc_command. . . . . : '%s'\n", ptr_handler->irc_command);
+        weechat_log_printf ("         command. . . . . . . : '%s'\n", ptr_handler->command);
+        weechat_log_printf ("         description. . . . . : '%s'\n", ptr_handler->description);
+        weechat_log_printf ("         arguments. . . . . . : '%s'\n", ptr_handler->arguments);
+        weechat_log_printf ("         arguments_description: '%s'\n", ptr_handler->arguments_description);
+        weechat_log_printf ("         completion_template. : '%s'\n", ptr_handler->completion_template);
+        weechat_log_printf ("         interval . . . . . . : %d\n",   ptr_handler->interval);
+        weechat_log_printf ("         remaining. . . . . . : %d\n",   ptr_handler->remaining);
+        weechat_log_printf ("         event. . . . . . . . : '%s'\n", ptr_handler->event);
+        weechat_log_printf ("         handler_args . . . . : '%s'\n", ptr_handler->handler_args);
+        weechat_log_printf ("         handler_pointer. . . : 0x%X\n", ptr_handler->handler_pointer);
+        weechat_log_printf ("         running. . . . . . . : %d\n",   ptr_handler->running);
+        weechat_log_printf ("         prev_handler . . . . : 0x%X\n", ptr_handler->prev_handler);
+        weechat_log_printf ("         next_handler . . . . : 0x%X\n", ptr_handler->next_handler);
+    }
+
+    weechat_log_printf ("\n");
+    weechat_log_printf ("  => modifiers:\n");
+    for (ptr_modifier = plugin->modifiers; ptr_modifier;
+         ptr_modifier = ptr_modifier->next_modifier)
+    {
+        weechat_log_printf ("\n");
+        weechat_log_printf ("       [modifier (addr:0x%X)]\n", ptr_modifier);
+        weechat_log_printf ("         type . . . . . . . . : %d\n",   ptr_modifier->type);
+        weechat_log_printf ("         command. . . . . . . : '%s'\n", ptr_modifier->command);
+        weechat_log_printf ("         modifier . . . . . . : 0x%X\n", ptr_modifier->modifier);
+        weechat_log_printf ("         modifier_args. . . . : '%s'\n", ptr_modifier->modifier_args);
+        weechat_log_printf ("         modifier_pointer . . : 0x%X\n", ptr_modifier->modifier_pointer);
+        weechat_log_printf ("         running. . . . . . . : %d\n",   ptr_modifier->running);
+        weechat_log_printf ("         prev_modifier. . . . : 0x%X\n", ptr_modifier->prev_modifier);
+        weechat_log_printf ("         next_modifier. . . . : 0x%X\n", ptr_modifier->next_modifier);
+    }
+}
