@@ -4,7 +4,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -68,7 +67,7 @@ extern int plugin_msg_handler_exec (char *, char *, char *);
 extern int plugin_cmd_handler_exec (char *, char *, char *);
 extern int plugin_timer_handler_exec ();
 extern int plugin_keyboard_handler_exec (char *, char *, char *);
-extern int plugin_event_handler_exec (char *, char *);
+extern int plugin_event_handler_exec (char *, int, char **);
 extern void plugin_handler_remove (t_weechat_plugin *,
                                    t_plugin_handler *);
 extern void plugin_handler_remove_all (t_weechat_plugin *);
@@ -89,5 +88,6 @@ extern void plugin_unload_all ();
 extern void plugin_reload_name (char *);
 extern void plugin_init (int);
 extern void plugin_end ();
+extern void plugin_print_log (t_weechat_plugin *);
 
 #endif /* plugins.h */
