@@ -4,7 +4,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /* weechat-lua.c: Lua plugin support for WeeChat */
@@ -216,7 +215,10 @@ weechat_lua_event_handler (t_weechat_plugin *plugin,
     {
         r = (int *) weechat_lua_exec (plugin, (t_plugin_script *)handler_pointer,
                                       SCRIPT_EXEC_INT,
-                                      handler_args, argv[0], NULL, NULL);
+                                      handler_args,
+                                      argv[0],
+                                      (argc >= 2) ? argv[1] : NULL,
+                                      (argc >= 3) ? argv[2] : NULL);
         if (r == NULL)
             ret = PLUGIN_RC_KO;
         else
@@ -769,6 +771,24 @@ weechat_lua_add_command_handler (lua_State *L)
             command = lua_tostring (lua_current_interpreter, -2);
             function = lua_tostring (lua_current_interpreter, -1);
             break;
+        case 3:
+            command = lua_tostring (lua_current_interpreter, -3);
+            function = lua_tostring (lua_current_interpreter, -2);
+            description = lua_tostring (lua_current_interpreter, -1);
+            break;
+        case 4:
+            command = lua_tostring (lua_current_interpreter, -4);
+            function = lua_tostring (lua_current_interpreter, -3);
+            description = lua_tostring (lua_current_interpreter, -2);
+            arguments = lua_tostring (lua_current_interpreter, -1);
+            break;
+        case 5:
+            command = lua_tostring (lua_current_interpreter, -5);
+            function = lua_tostring (lua_current_interpreter, -4);
+            description = lua_tostring (lua_current_interpreter, -3);
+            arguments = lua_tostring (lua_current_interpreter, -2);
+            arguments_description = lua_tostring (lua_current_interpreter, -1);
+            break;
         case 6:
             command = lua_tostring (lua_current_interpreter, -6);
             function = lua_tostring (lua_current_interpreter, -5);
@@ -1652,8 +1672,8 @@ weechat_lua_get_server_info (lua_State *L)
 	lua_pushnumber (lua_current_interpreter, ptr_server->autoreconnect_delay);
 	lua_rawset (lua_current_interpreter, -3);
 		
-	lua_pushstring (lua_current_interpreter, "command_line");
-	lua_pushnumber (lua_current_interpreter, ptr_server->command_line);
+	lua_pushstring (lua_current_interpreter, "temp_server");
+	lua_pushnumber (lua_current_interpreter, ptr_server->temp_server);
 	lua_rawset (lua_current_interpreter, -3);
 	
 	lua_pushstring (lua_current_interpreter, "address");
@@ -1953,7 +1973,7 @@ weechat_lua_get_irc_color (lua_State *L)
 static int
 weechat_lua_get_window_info (lua_State *L)
 {
-    t_plugin_window_info *window_info, *ptr_window;
+    t_plugin_window_info *window_info, *ptr_win;
     int i;
     
     /* make C compiler happy */
@@ -1977,40 +1997,43 @@ weechat_lua_get_window_info (lua_State *L)
     
     lua_newtable (lua_current_interpreter);
 
-    for (i = 0, ptr_window = window_info; ptr_window; ptr_window = ptr_window->next_window, i++)
+    i = 0;
+    for (ptr_win = window_info; ptr_win; ptr_win = ptr_win->next_window)
     {
 	lua_pushnumber (lua_current_interpreter, i);
 	lua_newtable (lua_current_interpreter);
 
 	lua_pushstring (lua_current_interpreter, "num_buffer");
-	lua_pushnumber (lua_current_interpreter, ptr_window->num_buffer);
+	lua_pushnumber (lua_current_interpreter, ptr_win->num_buffer);
 	lua_rawset (lua_current_interpreter, -3);
 		    
 	lua_pushstring (lua_current_interpreter, "win_x");
-	lua_pushnumber (lua_current_interpreter, ptr_window->win_x);
+	lua_pushnumber (lua_current_interpreter, ptr_win->win_x);
 	lua_rawset (lua_current_interpreter, -3);
 		    
 	lua_pushstring (lua_current_interpreter, "win_y");
-	lua_pushnumber (lua_current_interpreter, ptr_window->win_y);
+	lua_pushnumber (lua_current_interpreter, ptr_win->win_y);
 	lua_rawset (lua_current_interpreter, -3);
 	
 	lua_pushstring (lua_current_interpreter, "win_width");
-	lua_pushnumber (lua_current_interpreter, ptr_window->win_width);
+	lua_pushnumber (lua_current_interpreter, ptr_win->win_width);
 	lua_rawset (lua_current_interpreter, -3);
 	
 	lua_pushstring (lua_current_interpreter, "win_height");
-	lua_pushnumber (lua_current_interpreter, ptr_window->win_height);
+	lua_pushnumber (lua_current_interpreter, ptr_win->win_height);
 	lua_rawset (lua_current_interpreter, -3);
 
 	lua_pushstring (lua_current_interpreter, "win_width_pct");
-	lua_pushnumber (lua_current_interpreter, ptr_window->win_width_pct);
+	lua_pushnumber (lua_current_interpreter, ptr_win->win_width_pct);
 	lua_rawset (lua_current_interpreter, -3);
 	
 	lua_pushstring (lua_current_interpreter, "win_height_pct");
-	lua_pushnumber (lua_current_interpreter, ptr_window->win_height_pct);
+	lua_pushnumber (lua_current_interpreter, ptr_win->win_height_pct);
 	lua_rawset (lua_current_interpreter, -3);
 	
 	lua_rawset (lua_current_interpreter, -3);
+        
+        i++;
     }
     
     lua_plugin->free_window_info (lua_plugin, window_info);
