@@ -4,7 +4,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /* weechat-perl.c: Perl plugin support for WeeChat */
@@ -337,7 +336,10 @@ weechat_perl_event_handler (t_weechat_plugin *plugin,
     {
         r = (int *) weechat_perl_exec (plugin, (t_plugin_script *)handler_pointer,
                                        SCRIPT_EXEC_INT,
-                                       handler_args, argv[0], NULL, NULL);
+                                       handler_args,
+                                       argv[0],
+                                       (argc >= 2) ? argv[1] : NULL,
+                                       (argc >= 3) ? argv[2] : NULL);
         if (r == NULL)
             ret = PLUGIN_RC_KO;
         else
@@ -1463,7 +1465,7 @@ static XS (XS_weechat_get_server_info)
 	hv_store (server_hash_member, "autoconnect",          11, newSViv (ptr_server->autoconnect), 0);
         hv_store (server_hash_member, "autoreconnect",        13, newSViv (ptr_server->autoreconnect), 0);
         hv_store (server_hash_member, "autoreconnect_delay",  19, newSViv (ptr_server->autoreconnect_delay), 0);
-        hv_store (server_hash_member, "command_line",         12, newSViv (ptr_server->command_line), 0);
+        hv_store (server_hash_member, "temp_server",          11, newSViv (ptr_server->temp_server), 0);
 	hv_store (server_hash_member, "address",               7, newSVpv (ptr_server->address, 0), 0);
         hv_store (server_hash_member, "port",                  4, newSViv (ptr_server->port), 0);
 	hv_store (server_hash_member, "ipv6",                  4, newSViv (ptr_server->ipv6), 0);
@@ -1715,7 +1717,7 @@ static XS (XS_weechat_get_irc_color)
 
 static XS (XS_weechat_get_window_info)
 {
-    t_plugin_window_info *window_info, *ptr_window;
+    t_plugin_window_info *window_info, *ptr_win;
     int count;
     HV *window_hash_member;
     dXSARGS;
@@ -1737,17 +1739,17 @@ static XS (XS_weechat_get_window_info)
     if (!window_info)
 	XSRETURN_EMPTY;
     
-    for (ptr_window = window_info; ptr_window; ptr_window = ptr_window->next_window)
+    for (ptr_win = window_info; ptr_win; ptr_win = ptr_win->next_window)
     {
 	window_hash_member = (HV *) sv_2mortal((SV *) newHV());	        
         
-	hv_store (window_hash_member, "num_buffer",     10, newSViv (ptr_window->num_buffer), 0);
-        hv_store (window_hash_member, "win_x",           5, newSViv (ptr_window->win_x), 0);
-        hv_store (window_hash_member, "win_y",           5, newSViv (ptr_window->win_y), 0);
-        hv_store (window_hash_member, "win_width",       9, newSViv (ptr_window->win_width), 0);
-	hv_store (window_hash_member, "win_height",     10, newSViv (ptr_window->win_height), 0);
-	hv_store (window_hash_member, "win_width_pct",  13, newSViv (ptr_window->win_width_pct), 0);
-	hv_store (window_hash_member, "win_height_pct", 14, newSViv (ptr_window->win_height_pct), 0);
+	hv_store (window_hash_member, "num_buffer",     10, newSViv (ptr_win->num_buffer), 0);
+        hv_store (window_hash_member, "win_x",           5, newSViv (ptr_win->win_x), 0);
+        hv_store (window_hash_member, "win_y",           5, newSViv (ptr_win->win_y), 0);
+        hv_store (window_hash_member, "win_width",       9, newSViv (ptr_win->win_width), 0);
+	hv_store (window_hash_member, "win_height",     10, newSViv (ptr_win->win_height), 0);
+	hv_store (window_hash_member, "win_width_pct",  13, newSViv (ptr_win->win_width_pct), 0);
+	hv_store (window_hash_member, "win_height_pct", 14, newSViv (ptr_win->win_height_pct), 0);
 	
 	XPUSHs(newRV_inc((SV *) window_hash_member));
 	count++;
