@@ -4,7 +4,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /* weechat-python.c: Python plugin support for WeeChat */
@@ -258,7 +257,10 @@ weechat_python_event_handler (t_weechat_plugin *plugin,
     {
         r = (int *) weechat_python_exec (plugin, (t_plugin_script *)handler_pointer,
                                          SCRIPT_EXEC_INT,
-                                         handler_args, argv[0], NULL, NULL);
+                                         handler_args,
+                                         argv[0],
+                                         (argc >= 2) ? argv[1] : NULL,
+                                         (argc >= 3) ? argv[2] : NULL);
         if (r == NULL)
             ret = PLUGIN_RC_KO;
         else
@@ -1493,8 +1495,8 @@ weechat_python_get_server_info (PyObject *self, PyObject *args)
 	    Py_DECREF (key);
 	    Py_DECREF (value);
 	    
-	    key = Py_BuildValue("s", "command_line");
-	    value = Py_BuildValue("i", ptr_server->command_line);
+	    key = Py_BuildValue("s", "temp_server");
+	    value = Py_BuildValue("i", ptr_server->temp_server);
 	    PyDict_SetItem(server_hash_member, key, value);
 	    Py_DECREF (key);
 	    Py_DECREF (value);
@@ -1854,7 +1856,7 @@ weechat_python_get_irc_color (PyObject *self, PyObject *args)
 static PyObject *
 weechat_python_get_window_info (PyObject *self, PyObject *args)
 {
-    t_plugin_window_info *window_info, *ptr_window;
+    t_plugin_window_info *window_info, *ptr_win;
     PyObject *window_list, *window_list_member, *key, *value;
     
     /* make C compiler happy */
@@ -1877,53 +1879,53 @@ weechat_python_get_window_info (PyObject *self, PyObject *args)
     }
 
     window_info = python_plugin->get_window_info (python_plugin);
-    if  (!window_info)
+    if (!window_info)
 	return window_list;
 
-    for(ptr_window = window_info; ptr_window; ptr_window = ptr_window->next_window)
+    for (ptr_win = window_info; ptr_win; ptr_win = ptr_win->next_window)
     {
 	window_list_member = PyDict_New();
 	
 	if (window_list_member)
 	{
 	    key = Py_BuildValue("s", "num_buffer");
-	    value = Py_BuildValue("i", ptr_window->num_buffer);
+	    value = Py_BuildValue("i", ptr_win->num_buffer);
 	    PyDict_SetItem(window_list_member, key, value);
 	    Py_DECREF (key);
 	    Py_DECREF (value);
 	    
 	    key = Py_BuildValue("s", "win_x");
-	    value = Py_BuildValue("i", ptr_window->win_x);
+	    value = Py_BuildValue("i", ptr_win->win_x);
 	    PyDict_SetItem(window_list_member, key, value);
 	    Py_DECREF (key);
 	    Py_DECREF (value);
 	    
 	    key = Py_BuildValue("s", "win_y");
-	    value = Py_BuildValue("i", ptr_window->win_y);
+	    value = Py_BuildValue("i", ptr_win->win_y);
 	    PyDict_SetItem(window_list_member, key, value);
 	    Py_DECREF (key);
 	    Py_DECREF (value);
 
 	    key = Py_BuildValue("s", "win_width");
-	    value = Py_BuildValue("i", ptr_window->win_width);
+	    value = Py_BuildValue("i", ptr_win->win_width);
 	    PyDict_SetItem(window_list_member, key, value);
 	    Py_DECREF (key);
 	    Py_DECREF (value);
 	    
 	    key = Py_BuildValue("s", "win_height");
-	    value = Py_BuildValue("i", ptr_window->win_height);
+	    value = Py_BuildValue("i", ptr_win->win_height);
 	    PyDict_SetItem(window_list_member, key, value);
 	    Py_DECREF (key);
 	    Py_DECREF (value);
 	    
 	    key = Py_BuildValue("s", "win_width_pct");
-	    value = Py_BuildValue("i", ptr_window->win_width_pct);
+	    value = Py_BuildValue("i", ptr_win->win_width_pct);
 	    PyDict_SetItem(window_list_member, key, value);
 	    Py_DECREF (key);
 	    Py_DECREF (value);
 	    
 	    key = Py_BuildValue("s", "win_height_pct");
-	    value = Py_BuildValue("i", ptr_window->win_height_pct);
+	    value = Py_BuildValue("i", ptr_win->win_height_pct);
 	    PyDict_SetItem(window_list_member, key, value);
 	    Py_DECREF (key);
 	    Py_DECREF (value);
