@@ -4,7 +4,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /* weechat-ruby.c: Ruby plugin support for WeeChat */
@@ -297,7 +296,10 @@ weechat_ruby_event_handler (t_weechat_plugin *plugin,
     {
         r = (int *) weechat_ruby_exec (plugin, (t_plugin_script *)handler_pointer,
                                        SCRIPT_EXEC_INT,
-                                       handler_args, argv[0], NULL, NULL);
+                                       handler_args,
+                                       argv[0],
+                                       (argc >= 2) ? argv[1] : NULL,
+                                       (argc >= 3) ? argv[2] : NULL);
         if (r == NULL)
             ret = PLUGIN_RC_KO;
         else
@@ -1667,8 +1669,8 @@ weechat_ruby_get_server_info (VALUE class)
 			  INT2FIX(ptr_server->autoreconnect));
 	    rb_hash_aset (server_hash_member, rb_str_new2("autoreconnect_delay"),
 			  INT2FIX(ptr_server->autoreconnect_delay));
-	    rb_hash_aset (server_hash_member, rb_str_new2("command_line"),
-			  INT2FIX(ptr_server->command_line));
+	    rb_hash_aset (server_hash_member, rb_str_new2("temp_server"),
+			  INT2FIX(ptr_server->temp_server));
 	    rb_hash_aset (server_hash_member, rb_str_new2("address"),
 			  rb_str_new2(ptr_server->address));
 	    rb_hash_aset (server_hash_member, rb_str_new2("port"),
@@ -1908,7 +1910,7 @@ weechat_ruby_get_irc_color (VALUE class, VALUE color)
 static VALUE
 weechat_ruby_get_window_info (VALUE class)
 {
-    t_plugin_window_info *window_info, *ptr_window;
+    t_plugin_window_info *window_info, *ptr_win;
     VALUE window_list, window_list_member;
     
     /* make C compiler happy */
@@ -1931,26 +1933,26 @@ weechat_ruby_get_window_info (VALUE class)
     if (!window_info)
         return window_list;
     
-    for(ptr_window = window_info; ptr_window; ptr_window = ptr_window->next_window)
+    for (ptr_win = window_info; ptr_win; ptr_win = ptr_win->next_window)
     {
 	window_list_member = rb_hash_new ();
 
 	if (!NIL_P (window_list_member))
 	{
 	    rb_hash_aset (window_list_member, rb_str_new2("num_buffer"), 
-			  INT2FIX(ptr_window->num_buffer));
+			  INT2FIX(ptr_win->num_buffer));
 	    rb_hash_aset (window_list_member, rb_str_new2("win_x"),
-			  INT2FIX(ptr_window->win_x));
+			  INT2FIX(ptr_win->win_x));
 	    rb_hash_aset (window_list_member, rb_str_new2("win_y"),
-			  INT2FIX(ptr_window->win_y));
+			  INT2FIX(ptr_win->win_y));
 	    rb_hash_aset (window_list_member, rb_str_new2("win_width"),
-			  INT2FIX(ptr_window->win_width));
+			  INT2FIX(ptr_win->win_width));
 	    rb_hash_aset (window_list_member, rb_str_new2("win_height"),
-			  INT2FIX(ptr_window->win_height));
+			  INT2FIX(ptr_win->win_height));
 	    rb_hash_aset (window_list_member, rb_str_new2("win_width_pct"),
-			  INT2FIX(ptr_window->win_width_pct));
+			  INT2FIX(ptr_win->win_width_pct));
 	    rb_hash_aset (window_list_member, rb_str_new2("win_height_pct"),
-			  INT2FIX(ptr_window->win_height_pct));
+			  INT2FIX(ptr_win->win_height_pct));
 	    
 	    rb_ary_push (window_list, window_list_member);
 	}
